import java.awt.Color;
import java.awt.Font;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.event.KeyEvent;
import java.awt.event.KeyListener;
import java.awt.event.WindowEvent;
import java.awt.event.WindowListener;
import java.awt.image.BufferedImage;
import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.security.NoSuchAlgorithmException;
import java.security.SecureRandom;
import java.util.Arrays;
import java.util.HashSet;
import java.util.Random;
import java.util.Set;

import javax.swing.JFrame;
import javax.swing.JPanel;

public class CuttingFiguresVis {
	static final int MINNM = 10;
	static final int MAXNM = 100;

	static final int MINP = 0;
	static final int MAXP = 30;

	static final int MINK = 3;
	static final int MAXK = 10;

	static final int MIN_INCOME = 1;
	static final int MAX_INCOME = 100;

	class WeightedGenerator {
		Random rnd;

		int[] weight;
		int[] sum;

		public int next() {
			int p = rnd.nextInt(sum[sum.length - 1]);

			int l = -1, r = sum.length - 1;
			while (r - l > 1) {
				int c = (l + r) / 2;
				if (sum[c] > p) {
					r = c;
				} else {
					l = c;
				}
			}

			return r;
		}

		public WeightedGenerator(Random rnd, int maxWeight, int choiceCnt) {
			this.rnd = rnd;

			weight = new int[choiceCnt];
			for (int i=0; i < choiceCnt; i++) {
				weight[i] = rnd.nextInt(maxWeight) + 1;
			}

			sum = new int[choiceCnt];
			sum[0] = weight[0];
			for (int i=1; i < choiceCnt; i++) {
				sum[i] = sum[i-1] + weight[i];
			}
		}
	}

	class Figure {
		char[][] data;
		
		public Figure(char[][] data) {
			this.data = new char[data.length][];
			for (int i=0; i < data.length; i++) {
				this.data[i] = data[i].clone();
			}
		}

		public Figure(String[] data) {
			this.data = new char[data.length][];
			for (int i=0; i < data.length; i++) {
				this.data[i] = data[i].toCharArray();
			}
		}
		
		public Figure(Figure other) {
			this(other.data);
		}
		
		public Figure(long code) {
			int N = (int)(code % MAXK) + 1;
			code /= MAXK;
			
			int M = (int)(code % MAXK) + 1;
			code /= MAXK;
			
			this.data = new char[N][M];
			for (int i=0; i < N; i++) {
				for (int j=0; j < M; j++) {
					int value = (int)(code % 2);
					code /= 2;
					
					data[i][j] = (value == 1 ? 'X' : '.');
				}
			}
		}

		public String[] toStringArray() {
			String[] res = new String[data.length];
			for (int i=0; i < data.length; i++) {
				res[i] = new String(data[i]);
			}
			return res;
		}

		public Figure denormalize(Random rnd) {
			Figure res = new Figure(this);

			int rotationCnt = rnd.nextInt(4);
			for (int i=0; i < rotationCnt; i++) {
				res = res.rotate();
			}

			if (rnd.nextBoolean()) {
				res = res.reflectV();
			}

			if (rnd.nextBoolean()) {
				res = res.reflectH();
			}

			return res;
		}
			
		public Figure rotate() {
			char[][] newData = new char[data[0].length][data.length];
			for (int i=0; i < data.length; i++) {
				for (int j=0; j < data[i].length; j++) {
					newData[j][data.length - i - 1] = data[i][j];
				}
			}
			return new Figure(newData);
		}
		
		public Figure reflectV() {
			char[][] newData = new char[data.length][data[0].length];
			for (int i=0; i < data.length; i++) {
				for (int j=0; j < data[i].length; j++) {
					newData[data.length - i - 1][j] = data[i][j];
				}
			}
			return new Figure(newData);
		}
		
		public Figure reflectH() {
			char[][] newData = new char[data.length][data[0].length];
			for (int i=0; i < data.length; i++) {
				for (int j=0; j < data[i].length; j++) {
					newData[i][data[i].length - j - 1] = data[i][j];
				}
			}
			return new Figure(newData);
		}		
	}

	class TestCase {
		String[] board;
		int K, orderCnt, P;

		int[] orderPrice;
		String[][] orderFigure;

		public TestCase(String test) throws NoSuchAlgorithmException {
			SecureRandom rnd = SecureRandom.getInstance("SHA1PRNG");
			rnd.setSeed(Long.parseLong(test));

			int N = rnd.nextInt(MAXNM - MINNM + 1) + MINNM;
			int M = rnd.nextInt(MAXNM - MINNM + 1) + MINNM;
			P = rnd.nextInt(MAXP - MINP + 1) + MINP;

			board = new String[N];
			for (int i=0; i < N; i++) {
				StringBuilder builder = new StringBuilder();
				for (int j=0; j < M; j++) {
					builder.append(rnd.nextInt(100) < P ? 'X' : '.');
				}
				board[i] = builder.toString();
			}

			K = rnd.nextInt(MAXK - MINK + 1) + MINK;

			int minOrderCnt = (N * M) / 2;
			int maxOrderCnt = N * M;
			orderCnt = rnd.nextInt(maxOrderCnt - minOrderCnt + 1) + minOrderCnt;

			orderPrice = new int[orderCnt];
			for (int i=0; i < orderCnt; i++) {
				orderPrice[i] = rnd.nextInt(MAX_INCOME - MIN_INCOME + 1) + MIN_INCOME;
			}

			orderFigure = new String[orderCnt][];
			WeightedGenerator figureGen = new WeightedGenerator(rnd, 100, FIGURE_CODES[K].length);
			for (int i=0; i < orderCnt; i++) {
				orderFigure[i] = (new Figure(FIGURE_CODES[K][figureGen.next()])).denormalize(rnd).toStringArray();
			}
		}
	}
	
	Random rnd = new Random();
	Object keyMutex = new Object();
	Object plateMutex = new Object();
	
	Color[] FIGURE_COLORS = new Color[] {
		Color.BLUE, Color.CYAN, Color.GREEN, Color.MAGENTA, Color.ORANGE,
		Color.PINK, Color.YELLOW
	};
	
	class Drawer extends JPanel implements WindowListener, KeyListener {
		public void paint(Graphics g) {
			if (plate == null) {
				return;
			}
				
			synchronized (plateMutex) {
				BufferedImage image = new BufferedImage(width, height, BufferedImage.TYPE_INT_RGB);
				Graphics2D graphics = (Graphics2D)image.getGraphics();
				
				graphics.setColor(Color.WHITE);
				graphics.fillRect(0, 0, image.getWidth(), image.getHeight());
				
				int headerHeight = height - frame.getContentPane().getBounds().height;
				
				int availableWidth = (int)Math.floor(width * 0.8) - 10;
				int availableHeight = height - headerHeight - 10;
				
				int size = 1;
				while ((size + 1) * plate.length <= availableHeight &&
					(size + 1) * plate[0].length <= availableWidth) {
					size++;
				}
				
				graphics.setColor(Color.BLACK);
				
				for (int i=0; i < plate.length; i++) {
					for (int j=0; j < plate[i].length; j++) {
						graphics.drawRect(3 + size * j, 3 + size * i, size, size);
					}
				}
						
				for (int i=0; i < plate.length; i++) {
					for (int j=0; j < plate[i].length; j++) {
						if (plate[i][j] == 'X') {
							graphics.setColor(new Color(150, 75, 0));
							graphics.fillRect(5 + size * j, 5 + size * i, size-3, size-3);
						}
						if (plate[i][j] == 'Y' || plate[i][j] == '~') {
							Color figureColor = null;
							if (color[i][j] < FIGURE_COLORS.length) {
								figureColor = FIGURE_COLORS[color[i][j]];
							} else {
								figureColor = new Color(rnd.nextInt(256), rnd.nextInt(256), rnd.nextInt(256));
							}
							graphics.setColor(figureColor);
							graphics.fillRect(5 + size * j, 5 + size * i, size-3, size-3);
							if (plate[i][j] == '~') {
								graphics.setColor(Color.RED);
								graphics.fillRect(5 + size * j, 5 + size * i, size-3, size-3);
							}
						}
					}
				}
				
				int leftBorder = width - (int)Math.floor(width * 0.2);
				
				graphics.setFont(new Font("Arial", Font.BOLD, width / 50 - 1));
				graphics.setColor(Color.BLACK);
				
				String totalIncome = "Total income: " + score;
				graphics.drawChars(totalIncome.toCharArray(), 0, totalIncome.length(),
						leftBorder + 2, 19);
				
				if (curOrder < testCase.orderCnt) {
					String nextOrder = "Next order:";
					graphics.drawChars(nextOrder.toCharArray(), 0, nextOrder.length(),
							leftBorder + 2, 119);
					
					availableWidth = (int)Math.floor(width * 0.2) - 10;
					availableHeight = height - headerHeight - 135;
					
					size = 1;
					
					while ((size + 1) * testCase.K <= availableHeight &&
						(size + 1) * testCase.K <= availableWidth) {
						size++;
					}
					
					String[] curFigure = testCase.orderFigure[curOrder];
					
					for (int i=0; i < curFigure.length; i++) {
						for (int j=0; j < curFigure[0].length(); j++) {
							graphics.setColor(Color.BLACK);
							graphics.drawRect(3 + leftBorder + size * j, 128 + size * i, size, size);
							
							if (curFigure[i].charAt(j) == 'X') {
								graphics.setColor(Color.GRAY);
								graphics.fillRect(5 + leftBorder + size * j, 130 + size * i, size-3, size-3);
							}
						}
					}
					
					graphics.setColor(Color.BLACK);
					String orderIncome = "Order's income: " + testCase.orderPrice[curOrder];
					graphics.drawChars(orderIncome.toCharArray(), 0, orderIncome.length(),
							leftBorder + 2, 150 + size * testCase.K);
				}
				
				g.drawImage(image, 0, 0, image.getWidth(), image.getHeight(), null);
			}
		}
		
		public void windowActivated(WindowEvent event) {
			// do nothing
		}

		public void windowClosed(WindowEvent event) {
			// do nothing			
		}

		public void windowClosing(WindowEvent event) {
			safeExit(); 
		}

		public void windowDeactivated(WindowEvent event) {
			// do nothing
		}

		public void windowDeiconified(WindowEvent event) {
			// do nothing
		}

		public void windowIconified(WindowEvent event) {
			// do nothing
		}

		public void windowOpened(WindowEvent event) {
			// do nothing
		}

		public void keyPressed(KeyEvent event) {
			synchronized (keyMutex) {
				if (event.getKeyChar() == ' ') {
					keyMutex.notify();
				}
			}
		}

		public void keyReleased(KeyEvent event) {
			// do nothing
		}

		public void keyTyped(KeyEvent event) {
			// do nothing
		}
	}
	
	void blockUntilKeyPressed() throws InterruptedException {
		synchronized (keyMutex) {
			keyMutex.wait();
		}
	}
	
	int[] DX = new int[] {-1, 1, 0, 0};
	int[] DY = new int[] {0, 0, -1, 1};
	
	String cutFigure(char[][] plate, String[] figure, int[] decision) throws InterruptedException {
		Figure f = new Figure(figure);

		if (decision[0] < 0 || decision[0] > 3) {
			return "Wrong number of rotations: " + decision[0] + ".";
		}

		for (int i=0; i < decision[0]; i++) {
			f = f.rotate();
		}

		if (decision[1] < 0 || decision[1] > 1) {
			return "Wrong number of vertical reflections: " + decision[1] + ".";
		}

		for (int i=0; i < decision[1]; i++) {
			f = f.reflectV();
		}

		if (decision[2] < 0 || decision[2] > 1) {
			return "Wrong number of horizontal reflections: " + decision[2] + ".";
		}

		for (int i=0; i < decision[2]; i++) {
			f = f.reflectH();
		}

		synchronized (plateMutex) {
			for (int r=0; r < plate.length; r++) {
				for (int c=0; c < plate[0].length; c++) {
					if (plate[r][c] == '~') {
						plate[r][c] = 'Y';
					}
				}
			}
				
			for (int r=0; r < f.data.length; r++) {
				for (int c=0; c < f.data[0].length; c++) {
					if (f.data[r][c] == 'X') {
						int R = decision[3] + r;
						int C = decision[4] + c;
	
						if (R < 0 || R >= plate.length || C < 0 || C >= plate[0].length) {
							return "Attempt to cut the square outside of the plate: row " + R + ", column " + C + ".";
						}
	
						if (plate[R][C] != '.') {
							return "Attempt to cut the square that is already cut or of bad quality: row " + R + ", column " + C + ".";
						}
	
						plate[R][C] = '~';
					}
				}
			}
			
			Set<Integer> takenColors = new HashSet<Integer>();
			for (int r=0; r < plate.length; r++) {
				for (int c=0; c < plate[0].length; c++) {
					if (plate[r][c] == '~') {
						for (int dir=0; dir < DX.length; dir++) {
							if (r + DX[dir] >= 0 && r + DX[dir] < plate.length &&
								c + DY[dir] >= 0 && c + DY[dir] < plate[0].length &&
								color[r + DX[dir]][c + DY[dir]] != -1) {
								takenColors.add(color[r + DX[dir]][c + DY[dir]]);
							}
						}
					}
				}
			}
			
			int newColor = 0;
			while (takenColors.contains(newColor)) {
				newColor++;
			}
			
			for (int r=0; r < plate.length; r++) {
				for (int c=0; c < plate[0].length; c++) {
					if (plate[r][c] == '~') {
						color[r][c] = newColor;
					}
				}
			}
			
			curOrder++;
		}
		
		updatePicture();

		return "";
	}
	
	void updatePicture() throws InterruptedException {
		if (!draw) {
			return;
		}
		frame.repaint();
		if (waitKey) {
			blockUntilKeyPressed();
		} else {
			Thread.sleep(delay);
		}
	}
	
	int curOrder = 0;
	TestCase testCase = null;
	
	char[][] plate;
	int[][] color;
	int score;
	
	int runTest(String seed) throws InterruptedException {
		testCase = null;
		try {
			testCase = new TestCase(seed);
		}
		catch (Exception e) {
			System.err.println("ERROR: unable to generate testcase");
			e.printStackTrace();
			
			return 0;
		}
		
		writer.println(testCase.board.length);
		for (String row : testCase.board) {
			writer.println(row);
		}
		writer.println(testCase.K);
		writer.println(testCase.orderCnt);
		writer.flush();
		
		synchronized (plateMutex) {
			plate = new char[testCase.board.length][];
			for (int i=0; i < testCase.board.length; i++) {
				plate[i] = testCase.board[i].toCharArray();
			}
		}
		
		color = new int[plate.length][plate[0].length];
		for (int i=0; i < color.length; i++) {
			Arrays.fill(color[i], -1);
		}
		
		if (draw) {
			frame.setSize(width, height);
			frame.setTitle("Visualizer tool for problem CuttingFigures");
			frame.setResizable(false);
			frame.setVisible(true);
			
			updatePicture();
		}

		score = 0;

		for (int i=0; i < testCase.orderFigure.length; i++) {
			writer.println(testCase.orderFigure[i].length);
			for (String row : testCase.orderFigure[i]) {
				writer.println(row);
			}
			writer.println(testCase.orderPrice[i]);
			writer.flush();

			int retSize;
			int[] decision;
			
			try {
				retSize = Integer.parseInt(reader.readLine());
				decision = new int[retSize];
				for (int pos=0; pos < retSize; pos++) {
					decision[pos] = Integer.parseInt(reader.readLine());
				}
			}
			catch (Exception e) {
				System.err.println("ERROR: unable to parse return from " + (i+1) + "-th (1-based) call to processOrder.");
				return score;
			}

			if (decision.length == 0) {
				if (draw) {
					curOrder++;
					updatePicture();
				}
				continue;
			}

			String errorMsg = cutFigure(plate, testCase.orderFigure[i], decision);

			if (!"".equals(errorMsg)) {
				System.err.println("ERROR: invalid return from " + (i+1) + "-th (1-based) call to processOrder. " + errorMsg);
				return score;
			}

			score += testCase.orderPrice[i];
		}

		return score;
	}
	
	JFrame frame;
	Process solution;
	BufferedReader reader;
	PrintWriter writer;
	Drawer drawer;
	
	public CuttingFiguresVis() {
		if (draw) {
			frame = new JFrame();
			drawer = new Drawer();
			frame.getContentPane().add(drawer);
			frame.addWindowListener(drawer);
			frame.addKeyListener(drawer);
		}
		
		try {
			solution = Runtime.getRuntime().exec(solutionCmd);
		}
		catch (Exception e) {
			System.err.println("ERROR: unable to execute your solution");
			e.printStackTrace();
			System.exit(0);
		}
		
		reader = new BufferedReader(new InputStreamReader(solution.getInputStream()));
		writer = new PrintWriter(solution.getOutputStream());
        new ErrorStreamRedirector(solution.getErrorStream()).start();
		
		int income = -1;
		try {
			income = runTest(seed);
		} catch (Exception e) {
			System.out.println("ERROR: unexpected error");
			e.printStackTrace();
			System.exit(0);
		}
		
		System.out.println("Income = " + income);
		
		if (forceExit) {
			safeExit();
		}
	}
	
	void safeExit() {
		solution.destroy();
		System.exit(0);
	}
	
	static String seed = "1";
	static String solutionCmd = null;
	static int delay = 50;
	static boolean draw = true;
	static boolean waitKey = false;
	static boolean forceExit = false;
	
	static int height = 750;
	static int width = 750;
	
	public static void main(String[] args) throws Exception {
		for (int i = 0; i < args.length; i++) {
			if (args[i].equals("-exec")) {
				solutionCmd = args[++i];
			}
			if (args[i].equals("-delay")) {
				delay = Integer.parseInt(args[++i]);
			}
			if (args[i].equals("-novis")) {
				draw = false;
			}
			if (args[i].equals("-seed")) {
				seed = args[++i];
			}
			if (args[i].equals("-width")) {
				width = Integer.parseInt(args[++i]);
			}
			if (args[i].equals("-height")) {
				height = Integer.parseInt(args[++i]);
			}
			if (args[i].equals("-waitkey")) {
				waitKey = true;
			}
			if (args[i].equals("-forceexit")) {
				forceExit = true;
			}
		}
		
		if (solutionCmd == null) {
			System.err.println("ERROR: please specify the command to execute your solution " +
					"using -exec \"command\"");
			System.exit(0);
		}
		
		new CuttingFiguresVis();
	}
	
	class ErrorStreamRedirector extends Thread {
	    BufferedReader reader;
	    
	    public ErrorStreamRedirector(InputStream is) {
	        reader = new BufferedReader(new InputStreamReader(is));
	    }
	    
	    public void run() {
	        while (true) {
	        	String s = null;
	        	try {
					s = reader.readLine();
				} catch (Exception e) {
					e.printStackTrace();
					return;
				}
				if (s == null) {
					break;
				}
				System.err.println(s);
	        }
	    }
	}
	
	static final long[][] FIGURE_CODES = new long[][] {
		{},
		{100l},
		{301l},
		{702l, 711l},
		{1511l, 2321l, 1521l, 1503l, 3012l},
		{3131l, 18622l, 7922l, 3112l, 6231l, 4721l, 12122l, 12222l, 9422l, 4731l, 3104l, 12422l},
		{6331l, 12322l, 12522l, 49832l, 75623l, 50032l, 11122l, 6312l, 73932l, 57432l, 12641l, 50432l, 28732l, 
		11131l, 9541l, 75632l, 6305l, 75432l, 15941l, 9531l, 31832l, 55932l, 18922l, 18722l, 15931l, 63632l, 49732l, 
		9522l, 12613l, 63623l, 25241l, 38032l, 6341l, 12313l, 12622l},
		{108742l, 403642l, 57541l, 25341l, 459333l, 50632l, 76232l, 38241l, 447633l, 23922l, 75532l, 329242l, 63823l, 
		460033l, 74332l, 38232l, 201842l, 63832l, 438333l, 304242l, 459633l, 608433l, 425542l, 127642l, 50851l, 70232l, 88923l, 
		316642l, 41532l, 49114l, 201742l, 47541l, 894633l, 509633l, 24722l, 797033l, 50132l, 497233l, 76423l, 304442l, 202042l, 
		203242l, 57532l, 50832l, 800433l, 76432l, 354442l, 19131l, 38122l, 63732l, 74732l, 918833l, 19122l, 31932l, 441433l, 
		509224l, 230042l, 99532l, 509233l, 36722l, 25441l, 509242l, 22341l, 434842l, 63723l, 38132l, 25451l, 894833l, 62332l, 
		304842l, 89023l, 255242l, 62323l, 301142l, 214342l, 68732l, 76132l, 12751l, 50532l, 35132l, 99832l, 49932l, 12741l, 
		202442l, 25422l, 98223l, 12722l, 35141l, 12713l, 152842l, 12706l, 509033l, 217442l, 89223l, 596433l, 47132l, 115042l, 
		44632l, 75823l, 94232l, 459433l, 19151l, 75732l, 31941l, 75832l, 19141l, 31951l, 50232l},
		{4083643l, 803433l, 76523l, 153042l, 101851l, 503833l, 456733l, 509833l, 459833l, 8144234l, 3478543l, 498824l, 6854743l, 
		1018233l, 714033l, 302742l, 148723l, 76541l, 101832l, 3385543l, 153032l, 7162034l, 76532l, 83151l, 509842l, 610033l, 813233l, 
		1222852l, 511252l, 149523l, 561833l, 6908043l, 8117643l, 127742l, 7856834l, 919633l, 510833l, 913433l, 405242l, 1425652l, 511233l, 
		894933l, 134342l, 510824l, 89423l, 509342l, 354842l, 6457843l, 202542l, 115142l, 612852l, 217551l, 367842l, 115151l, 217542l, 
		422352l, 1099433l, 813252l, 611633l, 509433l, 444733l, 75932l, 13914043l, 75923l, 3681643l, 115161l, 4084843l, 92732l, 304942l, 
		509424l, 844652l, 1189233l, 441533l, 406842l, 101823l, 101332l, 153023l, 1670352l, 1324052l, 230242l, 664233l, 178842l, 435052l, 
		1626452l, 895333l, 447733l, 6957643l, 255442l, 4009243l, 3680243l, 3478643l, 435042l, 51061l, 2898852l, 100632l, 6808843l, 460433l, 
		268642l, 1273252l, 100332l, 6882843l, 6464443l, 460442l, 100323l, 664133l, 101723l, 889433l, 8147634l, 95551l, 100623l, 997233l, 
		486042l, 509724l, 870052l, 1223252l, 550033l, 51051l, 809833l, 816052l, 7360443l, 6957243l, 101751l, 391842l, 509742l, 800633l, 
		51032l, 51014l, 101732l, 190242l, 101132l, 460452l, 152942l, 239942l, 101123l, 87923l, 152932l, 7162434l, 304542l, 121542l, 
		1689252l, 204061l, 13616443l, 255332l, 561733l, 203642l, 76332l, 121551l, 6858043l, 2949652l, 9734834l, 166242l, 797433l, 306442l, 
		7354034l, 255342l, 6771043l, 895433l, 150223l, 204042l, 329442l, 7350634l, 306042l, 754033l, 202142l, 357642l, 599633l, 894733l, 
		196315l, 281242l, 403542l, 227142l, 405042l, 305042l, 6870243l, 3479243l, 49522l, 813652l, 7311243l, 801233l, 49514l, 50951l, 
		202642l, 319842l, 292642l, 44732l, 6957043l, 9741243l, 305842l, 255642l, 6858443l, 98332l, 3680843l, 510542l, 301542l, 454233l, 
		98323l, 7956034l, 510533l, 159942l, 753833l, 428742l, 919433l, 50932l, 611433l, 609733l, 203442l, 4084043l, 289542l, 99923l, 
		3478843l, 25561l, 151723l, 510024l, 3480043l, 100523l, 838352l, 99932l, 403842l, 920852l, 1626052l, 4840843l, 25551l, 3606043l, 
		498624l, 497433l, 25541l, 895033l, 795533l, 380442l, 510033l, 713833l, 919033l, 102061l, 460142l, 354642l, 507824l, 25522l, 
		2042452l, 342242l, 459533l, 803633l, 89123l, 102051l, 460133l, 50332l, 195923l, 25513l, 997033l, 2023152l, 404442l, 25507l, 
		3593443l, 3404443l, 140642l, 304642l, 243042l, 1123433l, 195942l, 609233l, 102023l, 1740052l, 4890443l, 75132l, 509133l, 431942l, 
		44751l, 153242l, 202242l, 102032l, 75123l, 44741l, 6767943l, 201942l, 7360843l, 3429643l, 813052l, 89323l, 7360834l, 7013634l, 
		802033l, 196515l, 47941l, 94332l, 4034443l, 404242l, 807633l, 313542l, 6857843l, 509442l, 3631243l, 1099633l, 76651l, 459733l, 
		596633l, 304342l, 612033l, 252342l, 9632343l, 498524l, 6783643l, 70332l, 246332l, 151523l, 127851l, 63941l, 38361l, 76632l, 
		178532l, 664433l, 127842l, 63951l, 1022452l, 38351l, 1216352l, 814452l, 664833l, 451133l, 610433l, 457142l, 63961l, 301942l, 
		38341l, 895633l, 76623l, 1021233l, 305242l, 1224052l, 332442l, 798633l, 38332l, 95832l, 38322l, 265542l, 797133l, 447833l, 
		704742l, 50732l, 97523l, 7348934l, 63923l, 6477643l, 70351l, 63932l, 70341l, 202842l, 183942l, 3680443l, 562033l, 608633l, 
		510624l, 812952l, 460233l, 203342l, 510633l, 230142l, 305742l, 316742l, 47932l, 460242l, 2042052l, 1222652l, 434942l, 101432l, 
		562433l, 50714l, 3391843l, 1247852l, 7063234l, 99023l},
		{786624l, 6945443l, 2023952l, 814833l, 9632743l, 1330452l, 920633l, 889552l, 128294844l, 6269043l, 26674853l, 598233l, 99132l, 
		128296044l, 1601452l, 299132l, 206649844l, 6467643l, 665233l, 708633l, 99123l, 107807253l, 7267634l, 84736853l, 1629652l, 7361234l, 332642l, 
		7267643l, 665252l, 9756043l, 3430043l, 268742l, 460342l, 7361243l, 78285653l, 268761l, 460333l, 3472743l, 2886252l, 357842l, 6087243l, 
		8145834l, 7355634l, 507124l, 6834843l, 7851034l, 6957143l, 9683543l, 13617043l, 53349653l, 117766644l, 9760434l, 405142l, 111315444l, 510742l, 
		4828443l, 510733l, 3202852l, 292742l, 1627452l, 947052l, 407342l, 510724l, 6873443l, 13890843l, 3682443l, 612124l, 29466453l, 79659253l, 
		609933l, 6858143l, 889533l, 114989044l, 6860043l, 107756453l, 6458243l, 612142l, 7776443l, 32717653l, 14230834l, 994333l, 8173043l, 54056053l, 
		306142l, 4904062l, 13018043l, 357742l, 53651453l, 510933l, 1798342l, 27840253l, 4084443l, 3460743l, 3479643l, 510942l, 786524l, 7064834l, 
		202742l, 6908443l, 3254852l, 1111842l, 1195533l, 292723l, 6856343l, 1019833l, 13914243l, 6483443l, 2043352l, 715633l, 808333l, 537452l, 
		1224252l, 3404643l, 202715l, 2045052l, 6454743l, 305942l, 5310462l, 4499443l, 612233l, 222630844l, 1217933l, 6780743l, 814652l, 4034843l, 
		4893643l, 6961662l, 1894052l, 8145734l, 8130443l, 612242l, 1279633l, 4298443l, 2044952l, 8061234l, 460533l, 407442l, 151923l, 5118443l, 
		678242l, 1217952l, 460542l, 1279652l, 400742l, 7959234l, 6921443l, 8073843l, 111322044l, 5722043l, 13616943l, 342342l, 3680643l, 79481453l, 
		371042l, 788652l, 7357234l, 7307634l, 1094233l, 460552l, 508624l, 1740152l, 405442l, 1551852l, 1689462l, 559133l, 9635543l, 457533l, 
		1689452l, 10095843l, 7363434l, 1074852l, 1478052l, 202342l, 8157634l, 6959243l, 1189433l, 129052044l, 8168843l, 1021833l, 3631643l, 6809243l, 
		914752l, 870152l, 1021842l, 55680453l, 1219833l, 14230634l, 6857943l, 52045253l, 3680343l, 3404543l, 27027453l, 479942l, 7307434l, 4090043l, 
		610233l, 920933l, 810233l, 799424l, 3990825l, 524752l, 204461l, 2911652l, 3889643l, 870252l, 786842l, 6529662l, 6269243l, 116149644l, 
		3391943l, 497524l, 204471l, 12909443l, 611842l, 460633l, 920952l, 8147834l, 497533l, 786824l, 27027353l, 3644643l, 460652l, 780424l, 
		108287244l, 715442l, 407042l, 457542l, 460642l, 711142l, 7267434l, 9645143l, 217075644l, 797533l, 1689352l, 1196233l, 77837153l, 715433l, 
		147142l, 7267443l, 797524l, 252742l, 715424l, 108488844l, 460661l, 29265653l, 204442l, 147151l, 1198252l, 1021742l, 1195833l, 767233l, 
		3989025l, 801433l, 6957443l, 2559252l, 1577252l, 715333l, 1224452l, 895133l, 2045252l, 6490443l, 6617562l, 7366834l, 7164034l, 715342l, 
		702242l, 816852l, 7366843l, 332542l, 610133l, 6457943l, 1305033l, 1993252l, 3270462l, 1740252l, 8989034l, 27840453l, 3684862l, 8061034l, 
		1629252l, 3668643l, 801442l, 7311643l, 7357034l, 3265662l, 3684843l, 243151l, 8124043l, 1299052l, 7677643l, 380642l, 13616643l, 243142l, 
		7162234l, 108941644l, 799324l, 1196133l, 4086543l, 243161l, 108463644l, 154906444l, 9264843l, 8998843l, 7307334l, 921033l, 814852l, 2026352l, 
		116200044l, 108538444l, 3596643l, 1226452l, 53298853l, 921052l, 4088043l, 115393644l, 10119843l, 112218435l, 191151l, 104064453l, 596733l, 1841742l, 
		915033l, 13222362l, 204242l, 111312144l, 659033l, 7677243l, 294242l, 607324l, 1241552l, 9264443l, 1841752l, 199932l, 79859653l, 51171l, 
		4892943l, 9734743l, 51161l, 505433l, 106546853l, 51151l, 816452l, 785116l, 204261l, 4297743l, 4902843l, 9639143l, 2045652l, 29113253l, 
		997333l, 1118233l, 13056862l, 1226052l, 816433l, 7217834l, 114990444l, 51132l, 2043652l, 54054853l, 4902862l, 4060443l, 6783843l, 4297843l, 
		51122l, 3681043l, 6858643l, 3480243l, 8160434l, 1049452l, 204161l, 8180062l, 3631443l, 51114l, 4896843l, 404642l, 609433l, 7360643l, 
		6809043l, 3378862l, 510242l, 895852l, 51108l, 510233l, 8493143l, 498924l, 2956052l, 510224l, 13616543l, 895833l, 9782634l, 29164053l, 
		804433l, 6883043l, 7352234l, 3103652l, 2149652l, 4902662l, 106527953l, 3252452l, 3590343l, 799033l, 921233l, 220250444l, 1218533l, 3681243l, 
		5318643l, 14326634l, 1125233l, 611833l, 79506853l, 726352l, 6793543l, 7352134l, 1426452l, 2489552l, 703624l, 611824l, 607424l, 11532462l, 
		8118043l, 664633l, 130688844l, 7981634l, 303542l, 7057434l, 498724l, 7217734l, 7063434l, 39220853l, 104090453l, 459933l, 89561l, 305442l, 
		1823152l, 7776843l, 204142l, 4040843l, 3315162l, 89541l, 53652853l, 364742l, 921252l, 89551l, 3480143l, 1305233l, 408842l, 53645153l, 
		89523l, 406942l, 810833l, 13914843l, 1628052l, 81183253l, 919133l, 1375652l, 7857234l, 29466053l, 100732l, 6808943l, 613652l, 1740452l, 
		4500843l, 3839243l, 5106462l, 1740462l, 408871l, 6086843l, 997133l, 100723l, 7727243l, 1189333l, 611742l, 26636753l, 486142l, 4083843l, 
		613633l, 6858543l, 808933l, 550133l, 3264162l, 1841852l, 10134843l, 1023252l, 9363643l, 81284853l, 27028853l, 8173234l, 1225752l, 816233l, 
		895533l, 108249444l, 1279333l, 219847244l, 810633l, 814552l, 4298043l, 14733662l, 76771l, 816252l, 7354234l, 4015643l, 303123l, 9735034l, 
		76761l, 221056844l, 940752l, 600924l, 10234043l, 8061634l, 305342l, 303142l, 10630834l, 156493644l, 95932l, 150323l, 108538044l, 6867143l, 
		76751l, 6957843l, 395042l, 1099733l, 9731543l, 1303533l, 7337243l, 76741l, 2037152l, 3455643l, 150332l, 3264262l, 76732l, 7367243l, 
		13821243l, 550233l, 7162834l, 76723l, 358042l, 7367234l, 562133l, 3429843l, 7677043l, 1125033l, 95951l, 1043152l, 24690462l, 785316l, 
		1627652l, 754833l, 2950052l, 13920443l, 1224152l, 11838462l, 1225852l, 6819143l, 8595443l, 2043452l, 54054653l, 1142352l, 6655662l, 197915l, 
		486242l, 919533l, 783124l, 665033l, 6470643l, 4890843l, 1021433l, 816152l, 486252l, 627152l, 7218034l, 6843143l, 106597653l, 3264462l, 
		55680853l, 203842l, 198123l, 109748844l, 27841653l, 406742l, 3480443l, 561933l, 4012443l, 9744443l, 1625952l, 3443043l, 294123l, 1350252l, 
		111335244l, 714833l, 798733l, 4844043l, 2905252l, 714842l, 798724l, 7007834l, 6479243l, 1772752l, 601024l, 108262044l, 611533l, 1279433l, 
		810542l, 714824l, 1124942l, 1019033l, 4092862l, 6783743l, 499024l, 3606243l, 10133043l, 6858243l, 58731253l, 607624l, 297532l, 499033l, 
		108337644l, 510124l, 7317643l, 1565524l, 664933l, 789424l, 711542l, 1842052l, 3398343l, 7116034l, 1835552l, 895733l, 510142l, 3467043l, 
		6908243l, 7268043l, 4090443l, 3429743l, 507933l, 7268034l, 388742l, 9735043l, 1099533l, 507924l, 345442l, 140761l, 140742l, 6958043l, 
		140751l, 1270333l, 800733l, 10131843l, 339142l, 714524l, 108336844l, 2508452l, 2042152l, 435725244l, 1003142l, 7115434l, 3417443l, 185542l, 
		178942l, 813752l, 9766843l, 2044052l, 6509043l, 52071253l, 2454462l, 3888243l, 613252l, 27030453l, 115343244l, 190342l, 1212433l, 8167643l, 
		1022542l, 800752l, 206861244l, 1099833l, 9742034l, 714542l, 606724l, 1022552l, 9742043l, 588442l, 207284044l, 699142l, 681542l, 216573044l, 
		639852l, 913533l, 6470843l, 473552l, 1183833l, 605542l, 27028053l, 802833l, 108109653l, 3436743l, 605524l, 6771143l, 2036352l, 1426052l, 
		166342l, 203742l, 503933l, 509933l, 166351l, 798233l, 4003043l, 3888143l, 509924l, 7314443l, 5885643l, 7165234l, 6461043l, 7350734l, 
		805033l, 997733l, 166361l, 509942l, 1223352l, 714642l, 8150634l, 775924l, 115392844l, 9543634l, 601224l, 1148652l, 102261l, 7956434l, 
		305142l, 53676653l, 1218833l, 278342l, 393442l, 707942l, 102271l, 108537844l, 547133l, 29468853l, 2029552l, 108866844l, 3683343l, 102251l, 
		714633l, 1125652l, 8496443l, 203542l, 2042252l, 7628043l, 102232l, 27640053l, 9495234l, 739052l, 1632852l, 8120843l, 9657943l, 130675644l, 
		108942444l, 4091243l, 102223l, 6960443l, 3264862l, 435152l, 230342l, 13917243l, 8595643l, 26649453l, 1791652l, 7673943l, 435161l, 230351l, 
		435142l, 562233l, 3478743l, 178732l, 326342l, 1022652l, 230361l, 997833l, 1022642l, 1521742l, 408442l, 383642l, 844761l, 5117243l, 
		52032253l, 230371l, 2483052l, 1020433l, 3683443l, 2098852l, 613242l, 190323l, 102161l, 9786034l, 6484043l, 7115334l, 6757662l, 844752l, 
		613233l, 1123833l, 102151l, 917533l, 108243144l, 27538453l, 613224l, 809233l, 55480053l, 54055253l, 55681653l, 78259653l, 102123l, 304742l, 
		111058453l, 4903262l, 664533l, 661533l, 408242l, 610833l, 714242l, 32718453l, 8169834l, 4037643l, 1207833l, 8179662l, 39019253l, 1329233l, 
		4903243l, 216573244l, 109748044l, 6855543l, 114989644l, 102132l, 7362443l, 1842452l, 613024l, 562642l, 9754843l, 447933l, 7362434l, 1842462l, 
		613033l, 53273453l, 5318843l, 116199244l, 10627434l, 613042l, 7163334l, 1223652l, 7165034l, 997433l, 2899052l, 406042l, 562633l, 703324l, 
		613052l, 114940044l, 219350644l, 109698444l, 447961l, 201332l, 7354834l, 814052l, 10637243l, 1247952l, 3888443l, 6504843l, 7013834l, 447952l, 
		306861l, 13617743l, 79860053l, 5004462l, 1944852l, 219449844l, 7832834l, 108892044l, 306842l, 9648443l, 115392444l, 8179643l, 6858843l, 4889962l, 
		705542l, 329542l, 128295244l, 58932053l, 117664435l, 216672444l, 814033l, 3988125l, 919833l, 7857034l, 775952l, 408261l, 6528462l, 1100133l, 
		3480843l, 807142l, 179051l, 4085643l, 2038752l, 511624l, 172742l, 6515643l, 13915643l, 179042l, 3478943l, 4841243l, 6805943l, 562542l, 
		3480862l, 3327862l, 7218443l, 562533l, 7063634l, 197523l, 511633l, 6960243l, 7218434l, 454342l, 27843253l, 302342l, 197551l, 106900053l, 
		81485653l, 4450443l, 154856844l, 675142l, 511652l, 1721552l, 197542l, 8144634l, 703424l, 754233l, 354742l, 813852l, 4248843l, 1626252l, 
		4894443l, 106880753l, 4500043l, 805233l, 3683643l, 5117043l, 8070743l, 1223452l, 6464643l, 612942l, 101923l, 5116943l, 509524l, 612933l, 
		1123533l, 101932l, 10131543l, 7115634l, 8150834l, 395561l, 509533l, 664333l, 9735634l, 783824l, 612952l, 408161l, 7882434l, 1100233l, 
		101951l, 219456444l, 454333l, 1216752l, 1452652l, 7013734l, 53652053l, 32415253l, 217882444l, 1016352l, 404342l, 1875152l, 249532l, 53702053l, 
		509542l, 172732l, 408142l, 1022852l, 2046462l, 8496243l, 58629653l, 606233l, 5718462l, 1632452l, 809933l, 9792443l, 777424l, 1022033l, 
		2042652l, 306642l, 27487653l, 3253252l, 1227252l, 777442l, 1676752l, 6822243l, 7014034l, 3657243l, 6086643l, 8074443l, 3479043l, 84434453l, 
		2035952l, 7163634l, 802133l, 7363643l, 7366643l, 1020133l, 1254252l, 405842l, 191842l, 129101644l, 1191952l, 6911243l, 196723l, 9741443l, 
		4905662l, 3814043l, 511352l, 6958643l, 1219552l, 511333l, 817652l, 780124l, 217076044l, 319942l, 562833l, 766633l, 1201833l, 6846243l, 
		53267153l, 3619043l, 196715l, 1174052l, 562842l, 7361734l, 562852l, 712342l, 511324l, 191823l, 3051652l, 117786444l, 6859643l, 3684043l, 
		4892043l, 6480843l, 754133l, 706342l, 1219533l, 3001252l, 3888843l, 972452l, 255751l, 281342l, 7349134l, 6958843l, 153461l, 1222752l, 
		113012035l, 4009443l, 108336244l, 1432052l, 153451l, 8141562l, 13311262l, 1528852l, 153442l, 4089843l, 26725653l, 4086843l, 6478043l, 1124242l, 
		153432l, 1018333l, 9738034l, 8144334l, 1324252l, 306542l, 785924l, 803533l, 1663962l, 753933l, 716033l, 219469644l, 203042l, 655933l, 
		81132453l, 1100433l, 766533l, 108539244l, 1186333l, 716052l, 196742l, 10132243l, 1124233l, 863952l, 714224l, 991833l, 780224l, 714233l, 
		9781643l, 355042l, 13593243l, 807833l, 216573644l, 3609243l, 4847243l, 802233l, 53451253l, 32516853l, 511452l, 1683152l, 2042852l, 108109253l, 
		3593543l, 255842l, 5885043l, 29467253l, 27027653l, 27840853l, 7264343l, 1629052l, 108941244l, 255861l, 108336144l, 291142l, 511433l, 511424l, 
		813152l, 153351l, 26827253l, 281442l, 127942l, 79557653l, 8024843l, 6960843l, 127951l, 813452l, 1626652l, 153323l, 511024l, 153332l, 
		13718843l, 3479343l, 4299243l, 7004734l, 511033l, 391942l, 153342l, 53752853l, 127961l, 106899653l, 81485253l, 127971l, 5117643l, 8180862l, 
		9635843l, 4896243l, 792224l, 751133l, 3681843l, 202942l, 2842352l, 7858434l, 52123253l, 1733952l, 8157034l, 53854453l, 1273433l, 6796643l, 
		608733l, 403942l, 8154834l, 10032443l, 712624l, 811342l, 101532l, 53651653l, 6859343l, 6870343l, 8105243l, 101523l, 2024752l, 255742l, 
		764452l, 27462253l, 3411143l, 117773244l, 4499643l, 6886043l, 1009442l, 8496843l, 1425852l, 1273452l, 495933l, 4087243l, 7362043l, 7355334l, 
		191561l, 7351034l, 1223052l, 690842l, 803833l, 3267262l, 65233653l, 4853643l, 306242l, 766833l, 8148434l, 6490043l, 2476752l, 6934043l, 
		911933l, 8170443l, 6855143l, 813352l, 6859443l, 3479443l, 255542l, 1507533l, 2042552l, 216672844l, 7165634l, 998033l, 9261143l, 1217152l, 
		815252l, 8992434l, 502333l, 10535043l, 5885243l, 6465243l, 55327653l, 811433l, 599833l, 255532l, 370361l, 1324452l, 9747634l, 2962452l, 
		114989244l, 153132l, 6528862l, 1224852l, 795933l, 153123l, 407642l, 9747643l, 108336444l, 191723l, 4085243l, 7364043l, 5722443l, 6528843l, 
		1222952l, 11634462l, 7776243l, 610533l, 7364034l, 111361644l, 153142l, 7258343l, 612424l, 11421034l, 9737834l, 1974352l, 713933l, 6895843l, 
		1015833l, 801933l, 612442l, 55378453l, 3634443l, 367942l, 4953462l, 5319243l, 813433l, 3682043l, 1626852l, 612433l},
		{537552l, 1224333l, 303932l, 303923l, 537561l, 3440180854l, 7365034l, 207386444l, 6458343l, 11337834l, 801542l, 5321843l, 10544443l, 
		423523263l, 106699453l, 801552l, 1224342l, 10544434l, 30304153l, 607824l, 8061434l, 9664743l, 218310844l, 607833l, 1224352l, 327488444l, 53349753l, 
		537571l, 3769165645l, 792924l, 8157434l, 390342l, 4708043l, 2862852l, 3259352l, 109155444l, 7357434l, 27590053l, 30304253l, 1704749254l, 218211644l, 
		1196524l, 13821443l, 108337744l, 16314834l, 7065034l, 3409498454l, 10108643l, 3433702854l, 7307734l, 6844743l, 53343553l, 1196533l, 9649243l, 19635472l, 
		109155344l, 48922453l, 3479743l, 1330552l, 216243463l, 4438243l, 5321743l, 117888844l, 1779152l, 40135253l, 2843152l, 2660952l, 115394044l, 10643634l, 
		7116434l, 221058444l, 1215633l, 303942l, 10643643l, 5321752l, 7349534l, 13720243l, 850495263l, 7307534l, 53349853l, 2661052l, 115808244l, 16314643l, 
		1196333l, 65259253l, 39224053l, 13720143l, 214719663l, 27455953l, 444732863l, 109358444l, 3268062l, 780642l, 14640434l, 88038853l, 19635672l, 14640443l, 
		107007253l, 108337844l, 793024l, 1074952l, 780624l, 130791244l, 4906043l, 4981568354l, 13891043l, 216243663l, 106901253l, 3690984045l, 9760343l, 111160853l, 
		4828643l, 4475052l, 2713252l, 5937643l, 60608453l, 11424634l, 1075052l, 810342l, 1330652l, 1484433l, 431268863l, 4854043l, 1768961654l, 4906062l, 
		116627444l, 110580844l, 9548034l, 9699643l, 130690444l, 7364943l, 6959443l, 188340044l, 9699634l, 8025243l, 7364934l, 1629452l, 219482044l, 396361l, 
		29467653l, 810324l, 3188762l, 7064934l, 810333l, 1484452l, 106699353l, 211557663l, 8061134l, 4056925l, 4086743l, 8989134l, 6129662l, 117786844l, 
		780524l, 81132653l, 32744072l, 108324644l, 12438843l, 3267652l, 7055934l, 65043453l, 2862652l, 1629433l, 8180262l, 7357134l, 117663253l, 3267662l, 
		218211444l, 19864862l, 13918843l, 13712743l, 1224633l, 1671271263l, 108255944l, 3215652l, 13037234l, 79835053l, 170202044l, 2042952l, 3788252l, 117780035l, 
		7357162l, 27564653l, 112224835l, 4739162l, 106699653l, 11338034l, 130767253l, 3596743l, 4906443l, 1577452l, 5118043l, 424536863l, 792624l, 5322043l, 
		4094462l, 55684853l, 4906462l, 1224652l, 10544234l, 4230343l, 4094443l, 632460663l, 7162334l, 109155644l, 122855244l, 9760643l, 108116053l, 639753663l, 
		7878062l, 4537562l, 108338044l, 128500044l, 13821743l, 58944253l, 29468053l, 53318353l, 42574453l, 28665853l, 4853825l, 219376844l, 106901053l, 130676444l, 
		1189533l, 6113852l, 4843525l, 10536643l, 156520844l, 1343952l, 9760634l, 1758854054l, 3788152l, 4057025l, 60608253l, 432487263l, 3682643l, 2968852l, 
		684742l, 9699434l, 8087234l, 117817844l, 13720443l, 108012053l, 2661252l, 8087243l, 633225663l, 3999943l, 26674953l, 232563644l, 653620063l, 780324l, 
		1224533l, 219470044l, 1017433l, 351942l, 396642l, 13821843l, 2043052l, 9266443l, 26675053l, 54911853l, 14640234l, 5772662l, 8180462l, 120006853l, 
		39271253l, 801524l, 28665753l, 3479843l, 8180434l, 155266444l, 801533l, 8180443l, 6536062l, 81592853l, 79711653l, 2150062l, 598333l, 2150052l, 
		1224552l, 32744053l, 81488853l, 206867444l, 8989434l, 19636072l, 1223852l, 217491444l, 1705361654l, 423115263l, 219848844l, 10505443l, 156890044l, 16337743l, 
		57331453l, 216244063l, 111126544l, 109761644l, 13918543l, 2149752l, 2502352l, 115394444l, 88039253l, 3258852l, 219496844l, 8173443l, 116212844l, 4844443l, 
		2043752l, 8142362l, 810942l, 235828863l, 3473216445l, 1885824454l, 34395253l, 1707190454l, 4844425l, 703524l, 4879643l, 52045453l, 1545552l, 8133643l, 
		114966044l, 216649244l, 206650244l, 1729753854l, 58744053l, 1483833l, 8460643l, 6113752l, 3435000854l, 6510552l, 5118843l, 26828053l, 1118333l, 9495634l, 
		106900953l, 212982463l, 108337244l, 28465653l, 8157834l, 117825644l, 8086843l, 1829552l, 117690035l, 5725243l, 7675543l, 8086834l, 2093927254l, 117032044l, 
		6879943l, 3788452l, 27494053l, 8061834l, 3788462l, 111126644l, 194771444l, 8902743l, 2043852l, 154908044l, 5322443l, 27815853l, 156678644l, 4079325l, 
		13011843l, 54062453l, 7215543l, 1595133l, 3410821654l, 10236043l, 8188872l, 4085825l, 4707443l, 109156044l, 108540044l, 2149852l, 634036863l, 6378325l, 
		1630052l, 2027952l, 13719643l, 8180162l, 818471l, 39232253l, 505533l, 435731644l, 2862552l, 117888453l, 4707343l, 40134853l, 818481l, 3449543l, 
		216676044l, 8173434l, 234609663l, 86413653l, 48922053l, 3682843l, 14324634l, 818433l, 6483843l, 1017152l, 54054753l, 6535243l, 3154852l, 1223752l, 
		218311244l, 818452l, 1049552l, 6535262l, 703724l, 1704749654l, 7115834l, 10614043l, 12915943l, 7065262l, 1484133l, 6855943l, 10939043l, 121216453l, 
		4079425l, 7116234l, 2510132854l, 7982034l, 13063262l, 9687043l, 4897043l, 235635644l, 8086634l, 108944144l, 111126844l, 27846553l, 8179762l, 6483543l, 
		33581053l, 1487781663l, 432486863l, 7215134l, 9795434l, 219462844l, 221349663l, 58936053l, 3480543l, 116301644l, 9249543l, 57331653l, 8086643l, 7065234l, 
		130880444l, 20171343l, 810716l, 27846653l, 6137843l, 156506044l, 33580953l, 1841942l, 3467143l, 1595152l, 3865243l, 3414072854l, 12065234l, 703824l, 
		1629852l, 120007253l, 607524l, 4844225l, 3439877654l, 35819253l, 995133l, 810742l, 3258552l, 703842l, 810733l, 78287253l, 211379163l, 1841952l, 
		154869644l, 5118543l, 1330852l, 5725643l, 7307834l, 116282035l, 7999843l, 130682044l, 8179862l, 216561444l, 206649944l, 9735143l, 81488453l, 218212044l, 
		1842142l, 5118643l, 52837672l, 73108853l, 10629034l, 8179843l, 9572034l, 27766253l, 129052444l, 2579152l, 6959643l, 1484233l, 4300062l, 8158034l, 
		607724l, 12640443l, 640564863l, 9735134l, 7116134l, 4300043l, 4105447245l, 6841574854l, 1866194454l, 1842152l, 8975643l, 32730453l, 3433286654l, 26841553l, 
		1603052l, 13910762l, 4844143l, 219351044l, 53350053l, 793242l, 109823653l, 2043542l, 1196633l, 6883143l, 424334463l, 52071653l, 2080875254l, 3007652l, 
		29475253l, 4897243l, 793224l, 8173162l, 864974463l, 8173143l, 117779635l, 2687852l, 111084053l, 53855253l, 3463982445l, 112224435l, 47297653l, 13821343l, 
		7365243l, 4086043l, 404742l, 7356434l, 117779644l, 130675844l, 3480343l, 4707643l, 4844125l, 2043552l, 130675853l, 14614734l, 11545262l, 9786834l, 
		818052l, 14721443l, 13894043l, 111338444l, 2937452l, 117788044l, 106900453l, 106540753l, 6517643l, 1042074363l, 9785943l, 863551263l, 128500844l, 818071l, 
		1119833l, 1292752l, 13617943l, 58958472l, 8071143l, 78490453l, 201532l, 219462644l, 11347543l, 114662853l, 6757862l, 588542l, 711924l, 52096453l, 
		55684053l, 12845234l, 130279153l, 8150734l, 1474725663l, 27538653l, 14616434l, 27844853l, 1188724l, 809424l, 6604772l, 3113462l, 809433l, 5119243l, 
		3091052l, 1329433l, 3683543l, 29466853l, 5119262l, 52148853l, 434982844l, 110944244l, 9688843l, 108867044l, 32729853l, 1593433l, 4957005645l, 640563663l, 
		6207425l, 11354243l, 1016742l, 2861852l, 1842252l, 6960543l, 55340453l, 222624344l, 108944444l, 4299452l, 7163034l, 4299443l, 1016752l, 222627444l, 
		6757762l, 107909253l, 79686253l, 6643162l, 7876634l, 79609253l, 11737262l, 4299343l, 3446481654l, 9648343l, 1628452l, 417998463l, 809333l, 14325134l, 
		108541644l, 5008614854l, 1099933l, 2862052l, 4299352l, 5004662l, 222253244l, 156698444l, 108671644l, 39272053l, 111058853l, 10535843l, 14318234l, 26827653l, 
		3459507654l, 4087343l, 5320843l, 108476644l, 130681844l, 5885443l, 54988053l, 7576862l, 8600062l, 3408742054l, 7612743l, 3771648854l, 9759243l, 9750634l, 
		7063834l, 653620863l, 219471244l, 73108053l, 8120943l, 6466843l, 2042352l, 13618143l, 117779444l, 9265243l, 3480643l, 66758653l, 5516062l, 58958453l, 
		6493643l, 8181643l, 9005243l, 222650444l, 8181634l, 432488063l, 9005234l, 1734352l, 8181662l, 4898443l, 216674444l, 818033l, 12933034l, 6207325l, 
		106900253l, 3480962l, 1483533l, 5823662l, 1863246454l, 6493243l, 117864853l, 13082472l, 8151034l, 9414843l, 55315053l, 3683743l, 26726053l, 6459043l, 
		4009543l, 739152l, 109357244l, 53854853l, 9658343l, 3758596854l, 2003142l, 245670844l, 5724943l, 124422644l, 817842l, 470436863l, 817852l, 2099062l, 
		3409499254l, 5010279254l, 206867644l, 9786234l, 6960343l, 113014635l, 84762453l, 2099052l, 729552l, 8121243l, 8158634l, 817833l, 5885843l, 13082462l, 
		106900153l, 627713663l, 155111244l, 6899043l, 1842552l, 9696343l, 6942343l, 802333l, 7308434l, 83136453l, 2098952l, 1223552l, 3481043l, 115392644l, 
		3190252l, 4077925l, 817871l, 27538853l, 109975244l, 809133l, 109753844l, 1452752l, 4299652l, 802352l, 104090853l, 7115734l, 126356053l, 3481062l, 
		107718853l, 7674343l, 55631653l, 116205044l, 26827353l, 97844053l, 3440180054l, 117612053l, 6075043l, 8164034l, 80269653l, 221057244l, 3052452l, 111361253l, 
		8181262l, 763933l, 3433728854l, 431676863l, 26827453l, 16377672l, 108268744l, 607142l, 1781812054l, 5885743l, 2899152l, 324314044l, 1521942l, 1011042l, 
		208288244l, 12526243l, 53273553l, 108944844l, 10627534l, 108109453l, 3641543l, 1704750454l, 55683653l, 588642l, 110580044l, 588652l, 217888244l, 106591553l, 
		4299643l, 8077543l, 1578324l, 9744343l, 78464453l, 222624644l, 9570434l, 9709143l, 7115534l, 607124l, 1842562l, 817752l, 26990353l, 54061653l, 
		7358034l, 9786243l, 711942l, 111322844l, 9648543l, 4087643l, 850393263l, 2861752l, 130689253l, 1483733l, 1636881l, 3409094654l, 11347843l, 817742l, 
		6528362l, 4105434045l, 14231634l, 9471234l, 8158534l, 1842662l, 8062034l, 9794043l, 817733l, 13062862l, 3480943l, 49658053l, 1842652l, 113006035l, 
		10099043l, 1407433l, 130689244l, 3540968054l, 27487853l, 9495434l, 9750834l, 817771l, 14616234l, 7365634l, 219811044l, 9750843l, 7365643l, 1628252l, 
		5105443l, 8181062l, 1100333l, 13617443l, 1636852l, 106956453l, 108541044l, 9639943l, 3267362l, 6528662l, 200608244l, 3481262l, 53854653l, 32721653l, 
		3814143l, 3433780854l, 1705561854l, 3481243l, 4086943l, 13734352l, 7262234l, 1881552l, 8015943l, 5295643l, 6467543l, 57131253l, 107909653l, 1710441654l, 
		222774463l, 2610852l, 422758263l, 6509443l, 106899853l, 7014134l, 6961043l, 5885143l, 7163534l, 14130462l, 3267452l, 137536444l, 4131252045l, 6517243l, 
		26725853l, 6924643l, 395961l, 129114044l, 4897843l, 81388053l, 606333l, 1475133l, 16298843l, 108540944l, 14333234l, 1601552l, 9648643l, 67162053l, 
		1862943254l, 606324l, 73107653l, 1759209654l, 106887153l, 6175862l, 17590734l, 1629152l, 6474043l, 222253644l, 221247663l, 58239253l, 2042752l, 3259652l, 
		261940863l, 55492853l, 3519962l, 1407633l, 9770043l, 7013934l, 7730443l, 9735843l, 606342l, 109974844l, 77837553l, 6841600854l, 40947453l, 864973663l, 
		52096853l, 47296853l, 10627834l, 191923l, 3267462l, 2642352l, 3737462l, 11433834l, 58944853l, 4078243l, 52025953l, 128096244l, 1842862l, 424333663l, 
		9735834l, 1842852l, 3683843l, 8181243l, 55693253l, 4298843l, 12265834l, 8163634l, 128271644l, 4890362l, 7231843l, 8062834l, 12275643l, 14232434l, 
		1100533l, 2861452l, 14325734l, 640564063l, 523068863l, 191951l, 2456062l, 14739362l, 106899753l, 191942l, 6960943l, 191961l, 6846343l, 26725753l, 
		13081772l, 111337744l, 7340443l, 1267152l, 1223152l, 1705562054l, 14232234l, 117031244l, 116678853l, 8990634l, 8062634l, 3251952l, 16321234l, 9688143l, 
		5885343l, 1885850454l, 6473843l, 14333034l, 53648353l, 7331962l, 1223133l, 53602853l, 115393244l, 40136053l, 2843952l, 972552l, 53620753l, 114593235l, 
		6482443l, 3684243l, 1119552l, 55486453l, 34394453l, 13183972l, 2073562l, 10237243l, 67161853l, 1980752l, 110970453l, 53683053l, 235828063l, 55532453l, 
		55384853l, 108541244l, 13081872l, 1215424l, 2661662l, 1100652l, 12771434l, 9743643l, 32529653l, 53656053l, 972652l, 116212044l, 2540752l, 2661652l, 
		49658453l, 117819244l, 219376244l, 109760844l, 4905862l, 1100633l, 6758062l, 8024943l, 7163834l, 108338444l, 6934243l, 6758072l, 39070453l, 81489653l, 
		1015942l, 54061253l, 1476148063l, 29176853l, 79864053l, 13617343l, 30104053l, 78266053l, 12833234l, 281571l, 6509143l, 1015933l, 3684143l, 154906844l, 
		9794443l, 84762053l, 1729948854l, 7163734l, 13082072l, 91290453l, 217895244l, 4905852l, 109830353l, 79810853l, 8180934l, 55693053l, 281551l, 13720862l, 
		764652l, 51245253l, 109974544l, 115494844l, 281542l, 3814243l, 30815253l, 8105443l, 7255843l, 40947653l, 281561l, 111322244l, 7011134l, 4087043l, 
		3051852l, 23090462l, 8180962l, 9670743l, 764552l, 109974644l, 106700053l, 4905762l, 109357644l, 6960643l, 4940762l, 107756653l, 27462353l, 599924l, 
		107719253l, 7852634l, 817252l, 10535143l, 115485035l, 7674743l, 8025043l, 599933l, 3619143l, 5158262l, 4905743l, 9688243l, 6796743l, 1804742l, 
		8062534l, 12958634l, 817233l, 8172043l, 7014234l, 8163434l, 3206052l, 79513253l, 206963644l, 104143253l, 3989425l, 3768742845l, 27640853l, 3435303254l, 
		220256844l, 108696844l, 3668743l, 4041243l, 3684443l, 116205644l, 86212853l, 3404743l, 116162444l, 108941444l, 4298243l, 3140517l, 13617143l, 13209472l, 
		109754444l, 1198352l, 7159834l, 3468362l, 14724443l, 5867143l, 2093979254l, 194791244l, 2836652l, 8182662l, 12856862l, 6226862l, 13921243l, 1704447254l, 
		4069025l, 113037635l, 3414375254l, 52124053l, 7367034l, 27003053l, 8063234l, 1707188854l, 678342l, 235830463l, 7265943l, 6295243l, 10633834l, 678352l, 
		1704548854l, 108898444l, 2006342l, 219401844l, 50470653l, 208130444l, 6908643l, 816952l, 107347153l, 27029053l, 53980653l, 4966262l, 1151852l, 816942l, 
		13515662l, 799724l, 219748044l, 204681l, 708733l, 332751l, 6481243l, 625894763l, 204671l, 708742l, 332742l, 3692557245l, 29100653l, 204661l, 
		3265862l, 26879653l, 332761l, 7776343l, 204642l, 111368044l, 53655253l, 104192853l, 8182562l, 6269143l, 4895243l, 2030352l, 966352l, 4501252l, 
		8598843l, 54061053l, 332771l, 14231034l, 3116452l, 1705209254l, 204623l, 1766362l, 7367043l, 3409095254l, 221069244l, 799524l, 204615l, 4092043l, 
		817052l, 78272453l, 206752244l, 9489434l, 6542462l, 1627552l, 817042l, 33380853l, 217888844l, 947171l, 8182634l, 14326034l, 817033l, 947152l, 
		221888444l, 3644743l, 204571l, 2585452l, 947161l, 9789034l, 3265852l, 204561l, 4904162l, 3436928854l, 91240853l, 13921043l, 58933653l, 39233653l, 
		143987644l, 65459653l, 207059444l, 27840353l, 128096444l, 6899661654l, 5270052l, 3468643l, 212980063l, 14739634l, 6261525l, 33582453l, 14739643l, 204542l, 
		10634034l, 2455252l, 104116053l, 3989125l, 807942l, 4298543l, 13515462l, 114990644l, 2455262l, 3265762l, 4904252l, 702342l, 8174643l, 79659453l, 
		6822247254l, 107762853l, 106630353l, 3839643l, 816652l, 4501243l, 6379525l, 14724143l, 1609971l, 10009243l, 4904262l, 6745162l, 1866497654l, 156495244l, 
		556742l, 27029253l, 112919235l, 115343644l, 7776643l, 79507053l, 54030253l, 6923962l, 6961243l, 7318043l, 27848053l, 5724043l, 3140317l, 1609933l, 
		108300644l, 12957134l, 1299152l, 8493943l, 50470853l, 10132643l, 7366743l, 4501052l, 417817863l, 13515362l, 107807653l, 1213924l, 2845552l, 4501043l, 
		4298643l, 8167162l, 1689571l, 81486053l, 14230734l, 81498053l, 1926352l, 53646753l, 128296444l, 7343643l, 53708453l, 204361l, 9789234l, 81542053l, 
		1689552l, 1605433l, 13616743l, 9674443l, 1689562l, 66759253l, 52077653l, 3544219254l, 4453643l, 1636052l, 212169663l, 13815143l, 870381l, 3001452l, 
		1705183854l, 129306444l, 870371l, 702324l, 10511843l, 109701644l, 8147962l, 204342l, 9758634l, 4084643l, 6480943l, 4904443l, 1729844854l, 4069225l, 
		114990844l, 870361l, 29126053l, 204315l, 8598643l, 8147934l, 108873244l, 5055862l, 870352l, 8174834l, 26739153l, 6269343l, 305542l, 808724l, 
		55271153l, 3409094854l, 1862892454l, 808733l, 7358834l, 7317843l, 791516l, 7367443l, 3684962l, 5106662l, 4198062l, 117767044l, 53571153l, 111315844l, 
		218714444l, 2905352l, 14724943l, 53654653l, 14326734l, 799124l, 3684943l, 1987152l, 4904462l, 799133l, 10133443l, 10121443l, 6831943l, 26940753l, 
		49657853l, 8484643l, 779124l, 15965034l, 808742l, 3839443l, 1432852l, 108262144l, 79659653l, 609533l, 4236643l, 8111643l, 109686044l, 3583662l, 
		84639253l, 847040463l, 2447333l, 81145253l, 207335244l, 10026343l, 81436453l, 26164872l, 11647262l, 3436928454l, 13920643l, 1221733l, 6719962l, 108262244l, 
		4500952l, 6269443l, 26623272l, 1705260054l, 108942044l, 3266462l, 9674043l, 9757743l, 108318344l, 76685653l, 3980125l, 1635652l, 12957434l, 8071543l, 
		30305653l, 3677275245l, 117665235l, 6962043l, 10494634l, 53452053l, 4842325l, 2905452l, 53654553l, 216249663l, 6962062l, 3839343l, 1487985663l, 2454862l, 
		78443253l, 895933l, 816633l, 111263253l, 1604652l, 2454852l, 55682453l, 109976044l, 112918835l, 4083943l, 10494534l, 3724762l, 15357243l, 7292652l, 
		3685062l, 6892743l, 115809644l, 1628133l, 358242l, 1768963254l, 1459052l, 54905553l, 9414643l, 79859553l, 755033l, 109357044l, 7203143l, 29470453l, 
		29272053l, 1729792854l, 358261l, 84460053l, 7063534l, 111341044l, 129933644l, 6294643l, 7367634l, 13798043l, 7367643l, 29318053l, 19641672l, 130714853l, 
		3685043l, 29170453l, 816552l, 53779053l, 600752l, 13260662l, 1527833l, 779152l, 895971l, 4006243l, 1478233l, 14231434l, 895961l, 4297943l, 
		3410770854l, 1478252l, 895952l, 219507644l, 11450034l, 1214124l, 1221833l, 31117253l, 305523l, 3980225l, 52032653l, 55391253l, 116628844l, 754933l, 
		8801234l, 52147653l, 29278453l, 9758043l, 3685243l, 116206444l, 6908343l, 66758853l, 12942034l, 1635371l, 79078253l, 99316053l, 6512152l, 55682053l, 
		114840844l, 219453044l, 5723643l, 499133l, 10952243l, 1635352l, 7777243l, 7956634l, 499124l, 65234453l, 358142l, 1177252l, 7358534l, 3443143l, 
		109755244l, 6380125l, 53654853l, 39225753l, 499161l, 130688653l, 122048844l, 9005043l, 1635452l, 499152l, 117792844l, 3510350445l, 203923l, 7662343l, 
		2454662l, 108542444l, 10238462l, 1206333l, 108526244l, 6961743l, 1214233l, 1276733l, 8599243l, 9663243l, 53670353l, 13897243l, 203942l, 52237053l, 
		10133143l, 395123l, 13884643l, 113015235l, 81183653l, 6961762l, 6512243l, 4041043l, 11771443l, 222637044l, 2074573654l, 32745653l, 142413644l, 219476044l, 
		816352l, 73511253l, 111367253l, 395142l, 6294843l, 1627852l, 106546953l, 709542l, 13477562l, 104115653l, 8175243l, 816333l, 4904862l, 6380225l, 
		2454652l, 53804453l, 111033253l, 3690177645l, 222645644l, 27028953l, 6961843l, 11348243l, 108502244l, 11456862l, 4904843l, 1068752l, 28667253l, 1222033l, 
		4298143l, 2402852l, 1635471l, 135962444l, 10494834l, 117769744l, 32720853l, 3256452l, 2454552l, 26700653l, 3660443l, 154509644l, 8493543l, 6207625l, 
		7358634l, 128296844l, 1729747354l, 2032752l, 115369244l, 163764044l, 117766744l, 111315544l, 7436762l, 7351834l, 112918635l, 84561653l, 117769844l, 6961862l, 
		1019133l, 128096844l, 31117053l, 3718375245l, 7777043l, 3266052l, 24690862l, 10529443l, 3266062l, 357942l, 4015843l, 3678081645l, 8987534l, 216537444l, 
		106547053l, 3679648245l, 2454562l, 32745672l, 4802862l, 3685262l, 4093043l, 19495634l, 34396853l, 1759208054l, 4093052l, 12246862l, 4500452l, 4291943l, 
		1757581054l, 383571l, 13719043l, 601124l, 4103054445l, 13822643l, 117395444l, 1474929663l, 1604333l, 1866496854l, 4500443l, 156903244l, 7980062l, 845516463l, 
		53676753l, 1781773054l, 12935043l, 6962472l, 222637244l, 3273662l, 1212533l, 8003143l, 217082044l, 9788043l, 5117343l, 6480343l, 8173843l, 601161l, 
		114989844l, 1221133l, 3264962l, 4092962l, 6534662l, 12925243l, 3634843l, 156494044l, 10210843l, 1704358354l, 78388053l, 6962443l, 10131943l, 3411123654l, 
		4092952l, 212980863l, 6270043l, 425959263l, 116137244l, 1619952l, 6962462l, 29478653l, 4092943l, 4902962l, 1221152l, 562333l, 5722843l, 7628243l, 
		128097644l, 8174034l, 307042l, 53451653l, 8174043l, 17589134l, 4896362l, 111324944l, 3988325l, 2439152l, 27846853l, 9351843l, 9795643l, 307061l, 
		53645553l, 110742644l, 1382033l, 107858853l, 114990044l, 307071l, 791852l, 6534862l, 6817786054l, 7368152l, 81285253l, 3417543l, 27468653l, 1382052l, 
		3763052l, 6847843l, 1690943963l, 4896343l, 12351662l, 27028153l, 3471643245l, 81487253l, 117664635l, 128295044l, 4075525l, 383742l, 46207272l, 7368134l, 
		3417562l, 11770243l, 5936443l, 1432452l, 4903043l, 3807943l, 8494743l, 108336644l, 79660053l, 3544218454l, 7628143l, 8995434l, 639971l, 9594834l, 
		52046053l, 4903062l, 13822543l, 2950252l, 1996452l, 78340853l, 115483335l, 211404663l, 4085443l, 10951043l, 687942l, 601324l, 1212624l, 306951l, 
		6138043l, 8079662l, 28666453l, 1212633l, 8148634l, 306961l, 110742544l, 4500243l, 639961l, 4500252l, 4093062l, 261942463l, 33581253l, 79583853l, 
		639952l, 1432152l, 7474862l, 306942l, 754333l, 117610235l, 104051853l, 40134653l, 306932l, 3327971l, 3685662l, 791716l, 1727952l, 27028253l, 
		81894853l, 5117143l, 8156443l, 1432142l, 4856843l, 306923l, 3264662l, 108492044l, 3685643l, 815633l, 13719343l, 78298453l, 5106862l, 4093252l, 
		30304853l, 815652l, 10950743l, 4093262l, 4834843l, 1944952l, 219079244l, 81486853l, 3327962l, 393542l, 218980044l, 383842l, 108942844l, 1757581254l, 
		13018843l, 601424l, 3414376054l, 156506444l, 108337044l, 53451353l, 8597643l, 5323243l, 601433l, 4093225l, 13922043l, 9742243l, 6510643l, 17192443l, 
		29478853l, 5323262l, 4093243l, 26163672l, 11427434l, 6818995654l, 40134553l, 52032353l, 109156844l, 9742234l, 14327034l, 5099143l, 3511936845l, 1207933l, 
		1199133l, 3435304054l, 11769943l, 1221433l, 4896643l, 5627425l, 11838862l, 8995634l, 36020053l, 3433689854l, 13921843l, 4912062l, 34193653l, 52659172l, 
		39032053l, 9312343l, 155008844l, 13719443l, 4903362l, 10123043l, 5936143l, 79866453l, 124429244l, 1945052l, 10851643l, 53451453l, 116628044l, 6464743l, 
		111386444l, 10495234l, 3434924654l, 15869034l, 217491644l, 111374444l, 6541643l, 8041562l, 1757228454l, 130272653l, 2508552l, 104166853l, 39025653l, 3264562l, 
		111386453l, 6541662l, 52038653l, 3366362l, 402342l, 306742l, 1626352l, 3980425l, 2508662l, 110742844l, 207066044l, 306751l, 3679668045l, 39227253l, 
		4085725l, 2508652l, 2074372854l, 306732l, 2031152l, 1167952l, 1580452l, 13088072l, 424336063l, 5936243l, 219350744l, 108336944l, 32719253l, 1432252l, 
		53554453l, 53577453l, 13822843l, 27640253l, 75136453l, 26662353l, 13057262l, 1758904854l, 27028453l, 260721663l, 7265143l, 115808844l, 6216625l, 18213662l, 
		26930453l, 222675444l, 8183262l, 11770643l, 110743244l, 53702253l, 2074574454l, 5722243l, 1811142l, 12947634l, 662333l, 8183243l, 425958663l, 1502333l, 
		8183234l, 3164462l, 203142l, 81285653l, 6817786454l, 108122453l, 9741543l, 32666372l, 27847253l, 117715635l, 9990343l, 991933l, 6138443l, 710233l, 
		108336344l, 4057225l, 562933l, 122049644l, 9818462l, 116922035l, 562942l, 422911263l, 4147062l, 33581653l, 9569234l, 991952l, 128397244l, 27027553l, 
		4903462l, 4499843l, 29469253l, 6954343l, 4658443l, 3479143l, 4076225l, 28666053l, 1529052l, 3562093045l, 471656063l, 3436728054l, 7778043l, 10951443l, 
		57029653l, 815452l, 1220633l, 111366644l, 5117843l, 6496243l, 73101153l, 19510734l, 2497230454l, 5081443l, 29417253l, 4093662l, 6822343l, 1145552l, 
		155316044l, 13516062l, 4903662l, 321037244l, 3414174454l, 792324l, 217082444l, 7777852l, 6822362l, 4093643l, 66752353l, 7777843l, 222644444l, 792371l, 
		1190224l, 1704396454l, 1627052l, 13593343l, 401542l, 200614844l, 807933l, 1190233l, 53653653l, 8174534l, 53753253l, 3609343l, 13516072l, 4903643l, 
		444324863l, 845478363l, 14533662l, 53645953l, 3465192045l, 128295644l, 154918844l, 111064853l, 424320363l, 4076125l, 2534252l, 7351134l, 11349043l, 5363062l, 
		5117743l, 417843663l, 425958863l, 6465443l, 1945252l, 3411124054l, 58935253l, 9787443l, 383161l, 114599635l, 1945262l, 2201252l, 10132343l, 108275044l, 
		562733l, 13822043l, 66760053l, 203132l, 114989444l, 107366053l, 137529844l, 219482444l, 218979644l, 3466778445l, 424434863l, 562742l, 14327634l, 203115l, 
		27640453l, 1190124l, 111386053l, 627558863l, 108115653l, 7628443l, 2453652l, 4076425l, 6518843l, 1190133l, 106732753l, 27027753l, 154857244l, 79866053l, 
		3634643l, 115808444l, 9690343l, 114989144l, 1431633l, 13593443l, 3609443l, 214821663l, 1529252l, 3677543l, 91264453l, 14327434l, 13018243l, 36019653l, 
		7715043l, 19609972l, 65436053l, 65183253l, 7264743l, 1757380854l, 3265252l, 3265262l, 5731262l, 75136853l, 6806343l, 3466755345l, 108336544l, 1381733l, 
		9811634l, 740761l, 9881462l, 108943244l, 10625934l, 11418362l, 7368243l, 1405933l, 5936843l, 632817663l, 306342l, 116627644l, 111071253l, 79762453l, 
		7368252l, 217492044l, 1863248054l, 219459644l, 130740044l, 4499543l, 563033l, 102490453l, 3265062l, 218310644l, 8182862l, 700742l, 1729766854l, 3768531445l, 
		30304453l, 6534643l, 3634543l, 3409088354l, 1704749054l, 1626752l, 8130843l, 639345663l, 1603933l, 2040352l, 4085125l, 1199852l, 563061l, 218979444l, 
		3265052l, 81895253l, 106802453l, 799824l, 563052l, 7368443l, 27027853l, 799833l, 563042l, 8754434l, 55681253l, 3439979254l, 13718943l, 6262225l, 
		7368434l, 815333l, 29469653l, 11839262l, 9496834l, 8072343l, 3479543l, 9757143l, 1009542l, 9252643l, 6511243l, 8572443l, 1555052l, 219446744l, 
		562952l, 1706987254l, 53753053l, 6818996054l, 54059253l, 3484545645l, 1781864054l, 815352l, 3409096054l, 92966853l, 1634452l, 219078844l, 5117443l, 8157134l, 
		12956462l, 4708843l, 3188733l, 1704748954l, 30916853l, 1381833l, 8182843l, 26164072l, 1193533l, 19386834l, 13059662l, 55327853l, 10135043l, 77862753l, 
		806033l, 106598053l, 6860143l, 55290453l, 806024l, 715742l, 129102044l, 4090243l, 7368834l, 12247262l, 715733l, 7368843l, 90988053l, 5873443l, 
		12453662l, 211761663l, 170215244l, 112075435l, 761433l, 32726453l, 1759206854l, 4035043l, 163744244l, 10033843l, 60198753l, 8993234l, 79481553l, 9543834l, 
		742252l, 10119943l, 27842453l, 3465191245l, 60206453l, 7259943l, 3411124854l, 29472153l, 52173653l, 4012643l, 863755263l, 814752l, 14733862l, 8073943l, 
		1356652l, 53503653l, 6532062l, 8176243l, 814742l, 1193552l, 6496843l, 117396044l, 8176234l, 814733l, 6532043l, 2453052l, 14319634l, 81297653l, 
		7320234l, 847041663l, 665333l, 8946034l, 3471642445l, 107813653l, 2886352l, 100941253l, 7267743l, 2886362l, 8184062l, 1219933l, 2303652l, 198342l, 
		3203052l, 1633852l, 7320134l, 14734062l, 198351l, 107961253l, 9316043l, 612333l, 920733l, 3409145254l, 1219952l, 14734034l, 1607852l, 19737472l, 
		6320443l, 788724l, 612324l, 271885244l, 10095943l, 665133l, 108918044l, 206662844l, 92967253l, 9932462l, 58604453l, 4847643l, 219520844l, 216574044l, 
		116156044l, 128302444l, 6219425l, 6487243l, 612342l, 114992244l, 6860243l, 108489044l, 10584434l, 82936053l, 79665653l, 715524l, 6809443l, 19126734l, 
		4503243l, 31118453l, 17167643l, 10033743l, 13914343l, 715533l, 112075335l, 715542l, 4839962l, 9645543l, 68788053l, 114992144l, 54058053l, 219363444l, 
		8055834l, 52126453l, 1021533l, 7267834l, 53653253l, 198323l, 78260453l, 835635663l, 84749653l, 217077644l, 508733l, 10640234l, 4633243l, 508724l, 
		54006053l, 198315l, 611924l, 15552643l, 1894252l, 10584234l, 221888844l, 611933l, 108948044l, 206862044l, 117667635l, 9818043l, 109748444l, 3752295254l, 
		1993352l, 6479643l, 1866296054l, 77850353l, 422745563l, 52084053l, 8161234l, 1894262l, 220250844l, 2039552l, 815052l, 9773234l, 27031253l, 1616724l, 
		5209262l, 79256053l, 9773243l, 12909543l, 611942l, 409281l, 6859843l, 10135343l, 122805644l, 4066843l, 8176434l, 1863044854l, 7361443l, 2497028854l, 
		5283043l, 7311843l, 409271l, 11758243l, 1021933l, 2559452l, 79154453l, 14315034l, 6809343l, 156544844l, 2047252l, 1021942l, 54058453l, 6921543l, 
		815033l, 221069644l, 8945734l, 2047262l, 1122333l, 6505943l, 78246753l, 788752l, 815024l, 409261l, 2453252l, 115349644l, 108122053l, 1894152l, 
		128397644l, 7827034l, 409242l, 1993452l, 12538243l, 9738243l, 111373653l, 7361434l, 53759253l, 6087443l, 9808234l, 79861053l, 159309553l, 219363644l, 
		6809143l, 13060062l, 814952l, 9652743l, 10135443l, 10020643l, 3991025l, 7935234l, 8145434l, 13094472l, 665352l, 3532662l, 1885902454l, 11734243l, 
		3540766454l, 5307043l, 3410923254l, 5170852l, 129530453l, 39020053l, 81337253l, 7959434l, 814933l, 8945834l, 114891244l, 56928253l, 13084872l, 6945543l, 
		7320434l, 6087643l, 1634052l, 7267534l, 847002363l, 9783034l, 27842053l, 3255052l, 665433l, 53653053l, 4494752l, 8802434l, 7166034l, 1503852l, 
		3409119854l, 5528043l, 7267543l, 10632434l, 3631843l, 207469044l, 4089943l, 94592453l, 1503833l, 2559352l, 114992444l, 665461l, 26418872l, 3464385645l, 
		10034043l, 55480853l, 9683943l, 3064452l, 6531662l, 79785453l, 4487843l, 7778443l, 112075635l, 6320243l, 3544017654l, 217882844l, 665452l, 2956152l, 
		2559652l, 2559662l, 1740352l, 9315443l, 129472753l, 6086743l, 8993734l, 53652953l, 409042l, 7268143l, 559933l, 29479253l, 6531462l, 796733l, 
		4502543l, 109874453l, 8597043l, 108892444l, 409061l, 4052752l, 6947043l, 114992844l, 130893644l, 409071l, 4502552l, 664733l, 7360743l, 106751653l, 
		313353663l, 921133l, 17595634l, 100941653l, 814233l, 408961l, 129204044l, 222656444l, 55680653l, 408971l, 3409196054l, 58779172l, 4502652l, 4090852l, 
		1426652l, 53369553l, 9894362l, 921152l, 4502643l, 1704371054l, 39245253l, 68787653l, 8118243l, 4090843l, 111325244l, 108112453l, 79861253l, 814252l, 
		11558062l, 1305133l, 216574644l, 6937243l, 32517653l, 814242l, 1757581654l, 1759207254l, 915152l, 102490053l, 1228052l, 6541243l, 27030853l, 4910443l, 
		7839962l, 5698843l, 9756443l, 45825653l, 4910462l, 216574544l, 117814635l, 814152l, 9002434l, 2911862l, 1305333l, 217077244l, 294342l, 408942l, 
		4090652l, 4090643l, 9002443l, 58932453l, 117395644l, 6496443l, 7702252l, 294351l, 7268243l, 7679243l, 4060643l, 4082025l, 7268234l, 55290053l, 
		8108443l, 3631543l, 108060453l, 2911852l, 294361l, 7166834l, 8065543l, 111312344l, 9782734l, 715042l, 206544344l, 4893162l, 222777663l, 27841853l, 
		294323l, 14733443l, 8021943l, 3420676854l, 9782743l, 110177644l, 107743853l, 21198362l, 8597243l, 3064252l, 81694453l, 425960063l, 915133l, 921333l, 
		4902762l, 6783943l, 4181619645l, 106881553l, 6461443l, 4893143l, 1220352l, 715024l, 6541262l, 10134743l, 6263143l, 10033243l, 715033l, 4502843l, 
		9738834l, 7166634l, 1220333l, 921352l, 1705564854l, 32440853l, 36020853l, 3408710354l, 921361l, 9661143l, 3615943l, 29119653l, 3484544845l, 1305433l, 
		114977444l, 4090552l, 3473229645l, 1305452l, 7267843l, 1740671l, 3264362l, 219078644l, 1740662l, 111387244l, 1740652l, 170093235l, 1868762l, 53478253l, 
		117875644l, 29472453l, 4090525l, 1426852l, 106597853l, 714942l, 13235162l, 106850853l, 9002043l, 7259143l, 7007934l, 1633752l, 1740562l, 3670243l, 
		714924l, 3991325l, 55480453l, 1740552l, 9315643l, 3272062l, 3087962l, 11532662l, 1534542l, 921433l, 3462343l, 27513453l, 94592853l, 221062644l, 
		4081825l, 112221035l, 48923253l, 107416853l, 109804753l, 116252044l, 921452l, 14727043l, 6840365254l, 2039152l, 206861444l, 235833663l, 219501044l,
		116199644l, 
		921471l, 115398644l, 7857434l, 58542453l, 14733762l, 10111643l, 27692453l, 130701644l, 7228743l, 3408894454l, 408661l, 3379062l, 1014333l, 14328234l, 
		8169243l, 408642l, 8160634l, 216574844l, 47433672l, 550333l, 27030653l, 107769253l, 154919244l, 7625143l, 10134943l, 470844863l, 9365643l, 2452952l, 
		130266353l, 707133l, 19966543l, 7354334l, 11773243l, 13915043l, 1977552l, 845618463l, 188326844l, 550361l, 27030553l, 486361l, 6087043l, 104500053l, 
		6860443l, 108489244l, 550352l, 486352l, 207488844l, 7337443l, 108947644l, 741571l, 707142l, 2812452l, 12538643l, 29164453l, 4850443l, 486342l, 
		4703262l, 111348044l, 7166534l, 10954043l, 106597753l, 14742472l, 117799244l, 6860462l, 3378962l, 16295843l, 79861653l, 114953444l, 4012543l, 77939553l, 
		108112853l, 486371l, 217789644l, 109749644l, 789524l, 798324l, 27743253l, 4091352l, 114991244l, 81119853l, 3271262l, 107309253l, 4894543l, 1716942454l, 
		798333l, 6859043l, 8496543l, 27646453l, 14627843l, 7352334l, 104065253l, 102381l, 7779643l, 130873844l, 102371l, 128398444l, 102361l, 7212634l, 
		1020633l, 8473243l, 8595543l, 12910243l, 1759006454l, 220252044l, 9661843l, 6321643l, 1617433l, 102351l, 6428462l, 14734862l, 9636643l, 102332l, 
		53652453l, 32415653l, 219823644l, 9755043l, 11421434l, 102323l, 632613663l, 1219033l, 1632952l, 102314l, 2483152l, 117837644l, 13031643l, 102309l, 
		7369862l, 9739634l, 575952l, 408561l, 2483162l, 99315653l, 424383863l, 122048444l, 81485453l, 4450643l, 1558252l, 8396062l, 108746444l, 6203125l, 
		9001834l, 408542l, 50471253l, 1227652l, 1707187654l, 9782043l, 78338453l, 2046052l, 58642453l, 8167562l, 1535252l, 7362243l, 14712234l, 1020533l, 
		11456443l, 53445153l, 408361l, 7882634l, 1873000054l, 1227633l, 1706834854l, 2527952l, 8074843l, 9748434l, 27015153l, 9661743l, 53881453l, 9748443l, 
		79859853l, 109704844l, 7369843l, 10631634l, 216982644l, 1183933l, 9261943l, 28668853l, 6470743l, 7369852l, 2452152l, 53652253l, 408342l, 7678843l, 
		9763634l, 3888343l, 7369834l, 22905672l, 16311343l, 183117644l, 7167262l, 1425952l, 7369752l, 13809443l, 73510853l, 13924062l, 7167234l, 53246472l, 
		3671843l, 129064844l, 113453653l, 3989725l, 785516l, 1218933l, 4859425l, 26854253l, 217884044l, 11446634l, 7369762l, 111364844l, 52058053l, 2848752l, 
		798342l, 79891053l, 208922444l, 716433l, 13311672l, 179171l, 1791862l, 137549644l, 847040863l, 116278635l, 53652153l, 716442l, 6630362l, 2452252l, 
		20044072l, 52136053l, 805333l, 215025663l, 3473209845l, 678513663l, 13311662l, 7857134l, 919933l, 716424l, 1791852l, 1633252l, 3466758645l, 129103244l, 
		17974734l, 4702852l, 6532862l, 2918052l, 217789044l, 52174453l, 179142l, 813952l, 7779352l, 3486158445l, 79065553l, 5414062l, 14628143l, 179151l, 
		1218733l, 114605235l, 206887244l, 128301244l, 7352634l, 377542l, 3435102454l, 716452l, 60408053l, 218714044l, 324205144l, 179161l, 221159244l, 7832934l, 
		62234453l, 216636644l, 8167843l, 3483739245l, 1218752l, 8994034l, 7779443l, 1510033l, 1574033l, 7362534l, 1227433l, 3473256045l, 8496343l, 117792244l, 
		1227452l, 179132l, 3716788045l, 8154362l, 3989825l, 13587143l, 6471043l, 7678643l, 30307253l, 27841253l, 610933l, 13043643l, 3209252l, 81234853l, 
		3330061054l, 1791752l, 4841443l, 9739334l, 79916453l, 110176844l, 19775962l, 9367243l, 78292053l, 6858943l, 7370062l, 7678543l, 27841053l, 77869253l, 
		997533l, 110176853l, 7833034l, 14628243l, 208499644l, 6948643l, 9739434l, 425148863l, 16311643l, 55688053l, 39221653l, 1227342l, 9661443l, 13785443l, 
		112221635l, 2956452l, 60205253l, 4831643l, 106882353l, 2553152l, 31117653l, 1227352l, 1426252l, 216575244l, 24716062l, 58636053l, 805133l, 4909662l, 
		20452872l, 65044853l, 611033l, 98942472l, 1762257654l, 3103852l, 5728443l, 805124l, 52057853l, 4909643l, 20468434l, 216660644l, 222682044l, 813942l, 
		38968853l, 1201452l, 6264325l, 8012443l, 8595843l, 1403133l, 8136843l, 3888543l, 6911643l, 117677235l, 1633052l, 7370034l, 2452452l, 222631644l, 
		9763434l, 216982844l, 7370043l, 217076444l, 109711244l, 2354452l, 53651853l, 107340653l, 111318644l, 13923362l, 33584053l, 8155034l, 13311362l, 4702652l, 
		9747834l, 153571l, 6859543l, 7959634l, 27849672l, 9261543l, 153581l, 170195444l, 652197663l, 7370462l, 1509833l, 79860253l, 106649253l, 3423943l, 
		6911343l, 8497043l, 110132753l, 13058062l, 153561l, 153542l, 216983244l, 7370443l, 13923352l, 4894043l, 153551l, 7370434l, 117813644l, 153523l, 
		207296844l, 58340853l, 9755534l, 3888643l, 207680444l, 208154444l, 84536853l, 9366843l, 130716053l, 153532l, 212979663l, 998252l, 4550262l, 130716044l, 
		108948844l, 113453253l, 418204863l, 2046562l, 14321234l, 27849653l, 691042l, 716224l, 4174750454l, 998233l, 2046552l, 6486643l, 3435302654l, 115091444l, 
		716233l, 13311462l, 111318544l, 4074325l, 691052l, 716242l, 4028643l, 11864062l, 116200844l, 56728053l, 3436929654l, 3270662l, 220251644l, 55583253l, 
		716252l, 6886243l, 13915843l, 1509733l, 220665844l, 1254352l, 610733l, 2046652l, 4493952l, 7665443l, 234405663l, 8496943l, 6911443l, 2037952l, 
		212979463l, 39228853l, 108745744l, 1174252l, 111341644l, 1632352l, 13923462l, 53651753l, 407842l, 154509244l, 13024443l, 116659953l, 19638472l, 1566324l, 
		8176843l, 55687253l, 300732l, 3270862l, 107309653l, 52228853l, 8159234l, 78247053l, 1209433l, 8146234l, 29215653l, 1124342l, 2086352l, 55089653l, 
		805433l, 52083453l, 716142l, 1707188054l, 219449944l, 7996743l, 1019933l, 716133l, 716152l, 81498453l, 790252l, 4044043l, 104295253l, 79860453l, 
		221485044l, 26777253l, 6859743l, 1124333l, 790242l, 4501643l, 216246463l, 7764643l, 9747843l, 104474053l, 217052444l, 8074243l, 790224l, 7833234l, 
		2046662l, 716124l, 4091652l, 1938752l, 1174152l, 14734562l, 108745844l, 8457543l, 7361934l, 1757582454l, 445545663l, 13923643l, 997933l, 6886143l, 
		219450244l, 65246453l, 4909243l, 2681552l, 27029653l, 7305443l, 60205653l, 3064862l, 3470433645l, 12522325l, 5728843l, 4091643l, 3064852l, 6471643l, 
		2451752l, 4450843l, 117616435l, 610333l, 407742l, 805824l, 55283553l, 110176453l, 786324l, 65240053l, 212979363l, 10133843l, 9747543l, 27840653l, 
		1202133l, 112212435l, 117677635l, 78362053l, 211455663l, 786316l, 106579153l, 14734662l, 9635943l, 11421134l, 3435302854l, 8168334l, 235738044l, 65441653l, 
		1632652l, 55291253l, 110176444l, 813533l, 4893743l, 1872798454l, 8596243l, 26166472l, 813542l, 58732053l, 8074643l, 156596044l, 1020333l, 29480053l, 
		7206243l, 8168362l, 76685253l, 79967253l, 106896353l, 130778044l, 13923662l, 1123933l, 58534753l, 355142l, 813552l, 3888943l, 4909262l, 62234053l, 
		222631044l, 217075844l, 2865662l, 1817342l, 715833l, 12077234l, 777552l, 3436626454l, 715824l, 632511663l, 8596443l, 206662644l, 26342372l, 3510349645l, 
		235533444l, 54057853l, 777542l, 7678043l, 13058462l, 129933244l, 108746044l, 2046852l, 8124443l, 7320834l, 1226852l, 104103253l, 8496643l, 8185762l, 
		7320843l, 2046862l, 3550520054l, 10442043l, 32718053l, 2451852l, 805724l, 4909062l, 1047040863l, 3434950054l, 4091425l, 4286243l, 109106444l, 3255652l, 
		53292753l, 3486132045l, 1509433l, 6478243l, 3889043l, 4091443l, 998133l, 219475444l, 1757203054l, 8074543l, 10640443l, 6478262l, 79103653l, 9662043l, 
		7780043l, 4091452l, 45824853l, 8145934l, 1201933l, 690942l, 10034462l, 777524l, 46483453l, 235539644l, 128301644l, 112076035l, 4065452l, 8481543l, 
		2830352l, 6505243l, 10034443l, 114605635l, 53401253l, 8804034l, 53651553l, 8185843l, 715842l, 2857952l, 1632552l, 111373244l, 8124243l, 445543263l, 
		34394053l, 7780862l, 8170543l, 26751853l, 1111942l, 7331043l, 851918463l, 5320152l, 1509133l, 12822843l, 9658743l, 78310853l, 1226552l, 52276053l, 
		40137653l, 5720062l, 6834943l, 9264943l, 13273562l, 7851134l, 1757279254l, 117773444l, 652809663l, 2045152l, 8186062l, 77895253l, 1691032863l, 16289443l, 
		65037153l, 53299053l, 4891562l, 7677743l, 1202233l, 46483653l, 113018035l, 1601533l, 109760444l, 207296444l, 32620053l, 1705562454l, 9806043l, 6490243l, 
		3563546054l, 7355534l, 4088143l, 106680753l, 9868762l, 371161l, 8583843l, 3430143l, 109750544l, 7727643l, 9000834l, 803924l, 8186034l, 371142l, 
		1605833l, 9364443l, 803933l, 9000843l, 65446653l, 53298953l, 8186043l, 108538844l, 6529862l, 1279533l, 53906853l, 108110053l, 14728243l, 10234843l, 
		380742l, 803952l, 1710238454l, 3408716654l, 12982634l, 14628943l, 11634862l, 79862853l, 7269634l, 407542l, 1023652l, 163750844l, 115495235l, 115495244l, 
		751952l, 7269643l, 2251652l, 77843853l, 7677843l, 3429943l, 84740053l, 1211133l, 128499644l, 9265043l, 3680743l, 1023671l, 5879143l, 4080625l, 
		110944444l, 206653044l, 1211124l, 7209534l, 425961663l, 9364243l, 12269234l, 1474623663l, 767033l, 9597634l, 8559843l, 108538644l, 4909043l, 3239852l, 
		10234643l, 1226652l, 1023633l, 6516443l, 6467743l, 217894844l, 53727853l, 1489204063l, 1279733l, 1509333l, 9745243l, 106903253l, 55686853l, 58957253l, 
		1559171l, 13924872l, 1124633l, 679732863l, 219457244l, 10542643l, 751933l, 1124642l, 7209543l, 3889243l, 58655253l, 14590634l, 56626453l, 8185862l, 
		232265844l, 47296253l, 114624835l, 1605733l, 40948053l, 117869235l, 6873543l, 53627053l, 110176244l, 4908962l, 7304734l, 7677443l, 57332853l, 79863253l, 
		111364053l, 407142l, 1279833l, 2787052l, 8497243l, 8076043l, 111328244l, 13695643l, 2764052l, 219472844l, 1762156054l, 108287344l, 9264643l, 129478953l, 
		53375853l, 14590834l, 24703262l, 12929934l, 54056253l, 424333063l, 1195933l, 220666044l, 67162453l, 34393853l, 1375852l, 786942l, 108463844l, 430962863l, 
		1863245254l, 1757584054l, 6467843l, 106693153l, 786916l, 1226252l, 79456453l, 786924l, 1279852l, 194778044l, 3270562l, 54937253l, 614024l, 1217552l, 
		11507062l, 2856352l, 2251352l, 9792643l, 1583652l, 767433l, 29481653l, 614042l, 614033l, 115400044l, 11053243l, 51245053l, 2591952l, 32724053l, 
		1279752l, 7355834l, 7615843l, 1124542l, 4134362l, 4878252l, 8170843l, 614052l, 4054243l, 432489663l, 221485244l, 1202533l, 14736262l, 2045352l, 
		77843553l, 614071l, 1094352l, 2037552l, 115759244l, 7355734l, 12922243l, 1116733l, 52250053l, 13502762l, 14736234l, 222671244l, 32523253l, 112125635l, 
		713424l, 4080362l, 2654752l, 7363543l, 2251452l, 314166463l, 6835043l, 29466253l, 9731943l, 7244443l, 9784843l, 232266044l, 129479053l, 9767634l, 
		1567124l, 58541053l, 7363534l, 108287444l, 9767643l, 9520834l, 5075143l, 13916443l, 460733l, 115488435l, 460742l, 786716l, 76275553l, 10638034l, 
		7983234l, 115091644l, 16588062l, 10638043l, 9762443l, 3430243l, 108313244l, 11422634l, 1202633l, 460752l, 106894753l, 32732853l, 47296453l, 111336844l, 
		14736162l, 3540966854l, 3430262l, 460761l, 32542453l, 3932733l, 3486118845l, 1187133l, 460771l, 4900043l, 144000844l, 767333l, 6957543l, 460781l, 
		1094333l, 7371262l, 9996643l, 424333263l, 3473543l, 652752l, 55693653l, 13069662l, 804324l, 786724l, 7164134l, 422809263l, 104092053l, 4062725l, 
		217079244l, 510333l, 3562727245l, 1631252l, 510324l, 83136853l, 9000443l, 10234243l, 2988652l, 65438453l, 52327272l, 1195152l, 767652l, 39044853l, 
		3672362l, 3409297654l, 4891043l, 77888353l, 8498043l, 812124l, 8143162l, 108538244l, 613861l, 8037034l, 214668663l, 6455143l, 812133l, 9363843l, 
		7371272l, 767633l, 613852l, 222253044l, 3889843l, 3681143l, 3889852l, 613842l, 6508043l, 812142l, 54056453l, 53471953l, 6858743l, 221961663l, 
		613833l, 80269253l, 1125342l, 106902553l, 1023033l, 3676872045l, 19125134l, 613824l, 6490843l, 9685143l, 3214262l, 1125333l, 6115352l, 85146453l, 
		14949662l, 110944844l, 1023052l, 1023042l, 6485643l, 32724853l, 217885644l, 6088843l, 6655872l, 117774035l, 58957672l, 1835952l, 112125235l, 1218352l, 
		112218835l, 106902653l, 4822243l, 6115452l, 219847444l, 117774044l, 7235143l, 5728243l, 58945653l, 7252743l, 58957653l, 12753434l, 1887952l, 3562304445l, 
		60205053l, 1218333l, 8075343l, 1762459254l, 114650435l, 117824444l, 613761l, 3606343l, 8186443l, 804524l, 60609653l, 46484053l, 1428633l, 5007796045l, 
		110579644l, 104064653l, 1551952l, 812233l, 8186434l, 613752l, 8075443l, 6265225l, 787042l, 3466804845l, 812224l, 27544853l, 444120863l, 128301044l, 
		613733l, 2036752l, 8186462l, 6521843l, 3332557654l, 219847644l, 78240353l, 613742l, 78311253l, 7261543l, 3446683254l, 7677343l, 1226152l, 219456644l, 
		2864152l, 6655862l, 613724l, 46616072l, 1704752054l, 9744643l, 4860043l, 109751244l, 27844053l, 24741662l, 129466353l, 9264543l, 787024l, 7057534l, 
		3889752l, 2864252l, 108287644l, 6655762l, 713142l, 6515843l, 28364053l, 108330344l, 3889743l, 3455843l, 774342l, 659133l, 13021243l, 113018435l, 
		2495952l, 7027162l, 1785552l, 1125133l, 11851262l, 2045452l, 183104444l, 222649844l, 4900843l, 1125142l, 510342l, 2025552l, 1226233l, 3474343l, 
		10631034l, 10014343l, 8036934l, 129114444l, 8151634l, 3890052l, 5320443l, 188320244l, 106883953l, 115092044l, 27791653l, 108945644l, 1350352l, 804642l, 
		21270472l, 112125035l, 2856933l, 9824072l, 7164434l, 9000134l, 804624l, 13298762l, 3330893254l, 7218134l, 639039663l, 10198243l, 4890762l, 53324653l, 
		804633l, 27843653l, 206886844l, 9744543l, 9793243l, 5886043l, 5719262l, 7727443l, 6529062l, 79487853l, 207284444l, 9793234l, 8497743l, 6264925l, 
		345542l, 104077253l, 712742l, 65485653l, 7362843l, 4088443l, 1710136854l, 55430053l, 3882343l, 32390053l, 6468443l, 13083272l, 435725444l, 7362834l, 
		8171334l, 6957943l, 216674044l, 8171343l, 345561l, 3455743l, 1023352l, 2045852l, 3540967254l, 424740863l, 6949162l, 712724l, 3014052l, 604733l, 
		6109152l, 261129663l, 1023342l, 712733l, 1023333l, 106902853l, 117869044l, 79456853l, 7960834l, 8896743l, 206550644l, 1863245654l, 56929653l, 3750352l, 
		9762034l, 1023361l, 11872443l, 216673844l, 222772863l, 54056853l, 108747244l, 613442l, 6858343l, 1710440054l, 10136843l, 613452l, 221485644l, 8171434l, 
		10637443l, 7882834l, 108249544l, 889867263l, 1716740854l, 52051653l, 2879952l, 5320243l, 3603143l, 10222243l, 1023442l, 6529243l, 9767043l, 10233943l, 
		812433l, 2045752l, 11670843l, 1023452l, 3239162l, 8497843l, 5320252l, 5017262l, 1225933l, 62033653l, 6265025l, 613424l, 3335886454l, 14330234l, 
		1023433l, 108537944l, 8037234l, 3252652l, 215433663l, 613433l, 135912844l, 9264343l, 3436575654l, 111363344l, 3160852l, 9363543l, 2864452l, 116150044l, 
		1567724l, 3890043l, 220666444l, 6529262l, 9546634l, 2892652l, 129479653l, 56921953l, 1225952l, 7677143l, 4852662l, 7217934l, 8498443l, 5319043l, 
		511761l, 6857143l, 26953453l, 7314543l, 7364143l, 1533433l, 6918343l, 9686743l, 8144734l, 217392844l, 6896410054l, 113856835l, 511752l, 3433280354l, 
		811533l, 14331634l, 4751862l, 811524l, 112219335l, 850699263l, 1324652l, 634036063l, 8144762l, 811542l, 802933l, 511824l, 207693644l, 613333l, 
		19636872l, 8906043l, 58938453l, 222656844l, 613342l, 511833l, 2855152l, 1125833l, 58541653l, 115092844l, 76282053l, 2027152l, 216672644l, 1125852l, 
		84548853l, 8152434l, 9784234l, 10032643l, 28313253l, 9546834l, 19724762l, 222771663l, 6090443l, 10136243l, 511861l, 13917343l, 29266453l, 511871l, 
		108947444l, 27843453l, 6328862l, 2044152l, 613352l, 57332053l, 26649553l, 212985663l, 431064863l, 511852l, 114889744l, 5526643l, 58737653l, 3941733l, 
		114940244l, 7953434l, 7059034l, 758333l, 9642343l, 8127243l, 1715162l, 55694453l, 5925662l, 3058052l, 613142l, 803024l, 10136143l, 613133l, 
		4038043l, 216244863l, 222733244l, 803033l, 11942062l, 613124l, 7364234l, 8083543l, 803042l, 3470836845l, 4279943l, 9633543l, 1715171l, 1508333l, 
		9768843l, 7218234l, 9784143l, 613152l, 7279952l, 9768834l, 7165434l, 1836352l, 58756853l, 10639243l, 32723353l, 108514844l, 54055053l, 8294062l, 
		4892443l, 108110853l, 10639234l, 106534353l, 5718862l, 56928853l, 6461143l, 111335644l, 106893553l, 1706885654l, 3679654845l, 115398844l, 216573144l,
		114889844l, 
		714742l, 12523525l, 1125733l, 3991625l, 2081076854l, 7858834l, 714724l, 26687953l, 6958243l, 1125752l, 5311262l, 5526543l, 714733l, 3622243l, 
		1762460854l, 13908643l, 811742l, 1630852l, 113434353l, 3665543l, 106831953l, 12541243l, 5718662l, 811833l, 14727443l, 5726443l, 10235643l, 3408792854l, 
		1507933l, 1607133l, 108539644l, 8905843l, 511524l, 1148752l, 113012435l, 511533l, 1533133l, 27032072l, 107820053l, 39246453l, 511542l, 3254052l, 
		1705563254l, 84447253l, 7218643l, 511552l, 108111253l, 42573253l, 9807243l, 3057752l, 8099043l, 714333l, 4293152l, 1022752l, 8999643l, 714324l, 
		1225252l, 58834453l, 6107552l, 7218634l, 29472853l, 8999634l, 4088843l, 10032943l, 6484443l, 55289853l, 4249043l, 7364434l, 1022742l, 851917663l, 
		835687263l, 714342l, 3563572054l, 15555643l, 3420878454l, 7364443l, 1225233l, 4037743l, 110668053l, 8152134l, 91039253l, 811842l, 107334353l, 445544063l, 
		4081225l, 29113453l, 110157553l, 130701244l, 7268443l, 40948853l, 7268434l, 6856743l, 216573344l, 3681443l, 2793552l, 216550044l, 1022952l, 29368853l, 
		7165134l, 8169962l, 1446352l, 2694352l, 86413253l, 8152234l, 3466765245l, 52129653l, 4853125l, 1125433l, 1022942l, 4182042445l, 8169943l, 6484243l, 
		10541843l, 6522043l, 652401663l, 582342l, 4808225l, 10136443l, 60004853l, 114890044l, 1692455263l, 116302444l, 8169934l, 8037634l, 1866499254l, 14727634l, 
		2044252l, 32742853l, 10235443l, 8037643l, 8187262l, 11660062l, 14727643l, 11444443l, 406242l, 5318743l, 1303933l, 1480733l, 107699953l, 7823934l, 
		4003143l, 4248943l, 32742872l, 5111143l, 10033043l, 220226844l, 5526843l, 108539444l, 46484853l, 78041953l, 114993644l, 111347644l, 511724l, 7314843l, 
		65284853l, 3890443l, 117798844l, 13917443l, 115496044l, 1702412063l, 7218543l, 766261l, 511733l, 7218534l, 3890462l, 115399244l, 7355043l, 783924l, 
		1225052l, 12912643l, 811033l, 216573444l, 5527243l, 4080925l, 2855552l, 3268862l, 221063244l, 4249243l, 216673244l, 9761043l, 9798834l, 3992225l, 
		19483534l, 811042l, 32421653l, 9798843l, 3058452l, 7218834l, 255932l, 207285644l, 7218843l, 5887243l, 7355034l, 3409497854l, 111328444l, 5319652l, 
		255951l, 4063625l, 255942l, 5310862l, 29473653l, 6895943l, 255961l, 79564053l, 4063643l, 55378853l, 1533833l, 8992634l, 255981l, 84409253l, 
		14225434l, 2962862l, 3692570445l, 2863252l, 9738234l, 2962852l, 255971l, 56928453l, 1716944054l, 2252062l, 114890444l, 104269253l, 627610463l, 54055453l, 
		82834453l, 783942l, 78259853l, 5319643l, 2252052l, 217392244l, 106893953l, 54055653l, 2044452l, 634035663l, 7269243l, 55334053l, 130726844l, 7363743l, 
		3260952l, 10638843l, 7269234l, 3463780845l, 19762862l, 612642l, 10032343l, 10135643l, 6896410454l, 84738453l, 612633l, 72039253l, 14710734l, 405942l, 
		612624l, 79558053l, 116211644l, 4601262l, 5319443l, 108294344l, 7884034l, 8170234l, 14736443l, 6530443l, 124442444l, 10541143l, 8126834l, 14538043l, 
		29266053l, 222772063l, 1795495236l, 5094043l, 1217533l, 1710439254l, 3682243l, 3657443l, 1781786054l, 6530462l, 6958743l, 2780752l, 216673044l, 24639662l, 
		9761243l, 3253452l, 27032053l, 9761234l, 117030844l, 76282453l, 7165834l, 7363834l, 6089843l, 1022142l, 13917743l, 106901653l, 31120053l, 4018843l, 
		98533672l, 1768760054l, 6204625l, 2962652l, 1762458454l, 4504043l, 612524l, 4504062l, 1126052l, 4847443l, 5310662l, 7363843l, 8126634l, 4063425l, 
		3409498054l, 612542l, 10541443l, 111362453l, 7112734l, 405542l, 7858534l, 52134653l, 1126033l, 219848244l, 1324352l, 30002453l, 8999043l, 6507343l, 
		216573744l, 80068853l, 6492043l, 12044062l, 111362444l, 4899443l, 766933l, 4899343l, 7269043l, 9737934l, 32743272l, 52072853l, 1022233l, 9737943l, 
		58939253l, 4953562l, 1599633l, 6530062l, 52328053l, 112220035l, 7269034l, 1703834463l, 4496352l, 46002872l, 639141663l, 13069243l, 27667053l, 32743253l, 
		1022242l, 32731253l, 4468752l, 2074271254l, 221553663l, 4063325l, 845822463l, 7858634l, 835790463l, 8906443l, 511142l, 1823952l, 12754862l, 32428053l, 
		19839672l, 13918043l, 84434853l, 3681943l, 216573844l, 54918353l, 6959043l, 52328072l, 417895263l, 1224952l, 58630053l, 1273533l, 6090043l, 1224933l, 
		13247962l, 7268943l, 511133l, 10638534l, 7268934l, 511124l, 64843253l, 109752044l, 235017663l, 79557853l, 1273552l, 79862653l, 9768134l, 4907243l, 
		1401452l, 1591933l, 143981044l, 79532653l, 851917263l, 81196053l, 109308044l, 4853725l, 3110052l, 1004742l, 26978853l, 4907262l, 84844053l, 217392444l, 
		3261252l, 219848444l, 84737253l, 53860853l, 918333l, 53957653l, 6377462l, 766733l, 78286053l, 7984834l, 3647843l, 1630652l, 42573653l, 8126534l, 
		142364044l, 3459533654l, 109698844l, 60608853l, 114940444l, 108895244l, 10032543l, 3992425l}
	};
}